# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'settings_main.ui'
#
# Created by: PyQt5 UI code generator 5.13.2
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_settings_main(object):
    def setupUi(self, settings_main):
        settings_main.setObjectName("settings_main")
        settings_main.resize(665, 1193)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(settings_main.sizePolicy().hasHeightForWidth())
        settings_main.setSizePolicy(sizePolicy)
        settings_main.setMaximumSize(QtCore.QSize(16777215, 16777215))
        settings_main.setLocale(QtCore.QLocale(QtCore.QLocale.C, QtCore.QLocale.AnyCountry))
        settings_main.setModal(True)
        self.verticalLayout = QtWidgets.QVBoxLayout(settings_main)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tabs = QtWidgets.QTabWidget(settings_main)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabs.sizePolicy().hasHeightForWidth())
        self.tabs.setSizePolicy(sizePolicy)
        self.tabs.setObjectName("tabs")
        self.tab_servers = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tab_servers.sizePolicy().hasHeightForWidth())
        self.tab_servers.setSizePolicy(sizePolicy)
        self.tab_servers.setObjectName("tab_servers")
        self.gridLayout = QtWidgets.QGridLayout(self.tab_servers)
        self.gridLayout.setContentsMargins(10, 10, 10, 10)
        self.gridLayout.setSpacing(5)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setContentsMargins(5, 5, 5, 0)
        self.horizontalLayout_2.setSpacing(5)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.input_checkbox_debug_mode = QtWidgets.QCheckBox(self.tab_servers)
        self.input_checkbox_debug_mode.setObjectName("input_checkbox_debug_mode")
        self.horizontalLayout_2.addWidget(self.input_checkbox_debug_mode)
        self.input_checkbox_debug_to_file = QtWidgets.QCheckBox(self.tab_servers)
        self.input_checkbox_debug_to_file.setEnabled(True)
        self.input_checkbox_debug_to_file.setObjectName("input_checkbox_debug_to_file")
        self.horizontalLayout_2.addWidget(self.input_checkbox_debug_to_file)
        self.input_lineedit_debug_file = QtWidgets.QLineEdit(self.tab_servers)
        self.input_lineedit_debug_file.setObjectName("input_lineedit_debug_file")
        self.horizontalLayout_2.addWidget(self.input_lineedit_debug_file)
        self.gridLayout.addLayout(self.horizontalLayout_2, 3, 1, 1, 3)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setContentsMargins(0, 5, 0, 5)
        self.verticalLayout_2.setSpacing(5)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.button_new_server = QtWidgets.QPushButton(self.tab_servers)
        self.button_new_server.setObjectName("button_new_server")
        self.verticalLayout_2.addWidget(self.button_new_server)
        self.button_edit_server = QtWidgets.QPushButton(self.tab_servers)
        self.button_edit_server.setObjectName("button_edit_server")
        self.verticalLayout_2.addWidget(self.button_edit_server)
        self.button_copy_server = QtWidgets.QPushButton(self.tab_servers)
        self.button_copy_server.setObjectName("button_copy_server")
        self.verticalLayout_2.addWidget(self.button_copy_server)
        self.button_delete_server = QtWidgets.QPushButton(self.tab_servers)
        self.button_delete_server.setObjectName("button_delete_server")
        self.verticalLayout_2.addWidget(self.button_delete_server)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem)
        self.gridLayout.addLayout(self.verticalLayout_2, 0, 3, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setContentsMargins(5, 5, 5, 5)
        self.horizontalLayout_3.setSpacing(5)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.input_checkbox_use_system_keyring = QtWidgets.QCheckBox(self.tab_servers)
        self.input_checkbox_use_system_keyring.setObjectName("input_checkbox_use_system_keyring")
        self.horizontalLayout_3.addWidget(self.input_checkbox_use_system_keyring)
        self.gridLayout.addLayout(self.horizontalLayout_3, 2, 1, 1, 3)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setContentsMargins(5, 5, 5, 5)
        self.horizontalLayout.setSpacing(5)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_update_interval_seconds = QtWidgets.QLabel(self.tab_servers)
        self.label_update_interval_seconds.setObjectName("label_update_interval_seconds")
        self.horizontalLayout.addWidget(self.label_update_interval_seconds)
        self.input_spinbox_update_interval_seconds = QtWidgets.QSpinBox(self.tab_servers)
        self.input_spinbox_update_interval_seconds.setMaximum(999)
        self.input_spinbox_update_interval_seconds.setObjectName("input_spinbox_update_interval_seconds")
        self.horizontalLayout.addWidget(self.input_spinbox_update_interval_seconds)
        self.label_interval_seconds = QtWidgets.QLabel(self.tab_servers)
        self.label_interval_seconds.setObjectName("label_interval_seconds")
        self.horizontalLayout.addWidget(self.label_interval_seconds)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.gridLayout.addLayout(self.horizontalLayout, 1, 1, 1, 3)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setContentsMargins(5, 5, 5, 0)
        self.horizontalLayout_4.setSpacing(5)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.input_checkbox_check_for_new_version = QtWidgets.QCheckBox(self.tab_servers)
        self.input_checkbox_check_for_new_version.setObjectName("input_checkbox_check_for_new_version")
        self.horizontalLayout_4.addWidget(self.input_checkbox_check_for_new_version)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem2)
        self.button_check_for_new_version_now = QtWidgets.QPushButton(self.tab_servers)
        self.button_check_for_new_version_now.setObjectName("button_check_for_new_version_now")
        self.horizontalLayout_4.addWidget(self.button_check_for_new_version_now)
        self.gridLayout.addLayout(self.horizontalLayout_4, 4, 1, 1, 3)
        self.list_servers = QtWidgets.QListWidget(self.tab_servers)
        self.list_servers.setMinimumSize(QtCore.QSize(0, 200))
        self.list_servers.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.list_servers.setResizeMode(QtWidgets.QListView.Adjust)
        self.list_servers.setObjectName("list_servers")
        self.gridLayout.addWidget(self.list_servers, 0, 1, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem3, 5, 1, 1, 1)
        self.tabs.addTab(self.tab_servers, "")
        self.tab_display = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tab_display.sizePolicy().hasHeightForWidth())
        self.tab_display.setSizePolicy(sizePolicy)
        self.tab_display.setObjectName("tab_display")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.tab_display)
        self.gridLayout_2.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_2.setSpacing(5)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.groupbox_display_size = QtWidgets.QGroupBox(self.tab_display)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupbox_display_size.sizePolicy().hasHeightForWidth())
        self.groupbox_display_size.setSizePolicy(sizePolicy)
        self.groupbox_display_size.setObjectName("groupbox_display_size")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.groupbox_display_size)
        self.horizontalLayout_5.setContentsMargins(10, 10, 10, 10)
        self.horizontalLayout_5.setSpacing(5)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.gridLayout_14 = QtWidgets.QGridLayout()
        self.gridLayout_14.setContentsMargins(5, 5, 5, 5)
        self.gridLayout_14.setSpacing(5)
        self.gridLayout_14.setObjectName("gridLayout_14")
        self.input_radiobutton_short_display = QtWidgets.QRadioButton(self.groupbox_display_size)
        self.input_radiobutton_short_display.setObjectName("input_radiobutton_short_display")
        self.gridLayout_14.addWidget(self.input_radiobutton_short_display, 0, 1, 1, 1)
        self.input_radiobutton_long_display = QtWidgets.QRadioButton(self.groupbox_display_size)
        self.input_radiobutton_long_display.setObjectName("input_radiobutton_long_display")
        self.gridLayout_14.addWidget(self.input_radiobutton_long_display, 0, 0, 1, 1)
        self.horizontalLayout_5.addLayout(self.gridLayout_14)
        self.gridLayout_2.addWidget(self.groupbox_display_size, 0, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem4, 11, 0, 1, 1)
        self.groupbox_detailed_summary_popup = QtWidgets.QGroupBox(self.tab_display)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupbox_detailed_summary_popup.sizePolicy().hasHeightForWidth())
        self.groupbox_detailed_summary_popup.setSizePolicy(sizePolicy)
        self.groupbox_detailed_summary_popup.setObjectName("groupbox_detailed_summary_popup")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupbox_detailed_summary_popup)
        self.gridLayout_3.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_3.setSpacing(5)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.gridLayout_13 = QtWidgets.QGridLayout()
        self.gridLayout_13.setContentsMargins(5, 5, 5, 5)
        self.gridLayout_13.setSpacing(5)
        self.gridLayout_13.setObjectName("gridLayout_13")
        self.input_radiobutton_close_details_clicking = QtWidgets.QRadioButton(self.groupbox_detailed_summary_popup)
        self.input_radiobutton_close_details_clicking.setObjectName("input_radiobutton_close_details_clicking")
        self.buttongroup_close_statusbar = QtWidgets.QButtonGroup(settings_main)
        self.buttongroup_close_statusbar.setObjectName("buttongroup_close_statusbar")
        self.buttongroup_close_statusbar.addButton(self.input_radiobutton_close_details_clicking)
        self.gridLayout_13.addWidget(self.input_radiobutton_close_details_clicking, 1, 1, 1, 1)
        self.input_radiobutton_popup_details_clicking = QtWidgets.QRadioButton(self.groupbox_detailed_summary_popup)
        self.input_radiobutton_popup_details_clicking.setObjectName("input_radiobutton_popup_details_clicking")
        self.buttongroup_popup_statuswindow = QtWidgets.QButtonGroup(settings_main)
        self.buttongroup_popup_statuswindow.setObjectName("buttongroup_popup_statuswindow")
        self.buttongroup_popup_statuswindow.addButton(self.input_radiobutton_popup_details_clicking)
        self.gridLayout_13.addWidget(self.input_radiobutton_popup_details_clicking, 1, 0, 1, 1)
        self.input_radiobutton_popup_details_hover = QtWidgets.QRadioButton(self.groupbox_detailed_summary_popup)
        self.input_radiobutton_popup_details_hover.setObjectName("input_radiobutton_popup_details_hover")
        self.buttongroup_popup_statuswindow.addButton(self.input_radiobutton_popup_details_hover)
        self.gridLayout_13.addWidget(self.input_radiobutton_popup_details_hover, 0, 0, 1, 1)
        self.input_radiobutton_close_details_hover = QtWidgets.QRadioButton(self.groupbox_detailed_summary_popup)
        self.input_radiobutton_close_details_hover.setObjectName("input_radiobutton_close_details_hover")
        self.buttongroup_close_statusbar.addButton(self.input_radiobutton_close_details_hover)
        self.gridLayout_13.addWidget(self.input_radiobutton_close_details_hover, 0, 1, 1, 1)
        self.input_radiobutton_close_details_clicking_somewhere = QtWidgets.QRadioButton(self.groupbox_detailed_summary_popup)
        self.input_radiobutton_close_details_clicking_somewhere.setObjectName("input_radiobutton_close_details_clicking_somewhere")
        self.buttongroup_close_statusbar.addButton(self.input_radiobutton_close_details_clicking_somewhere)
        self.gridLayout_13.addWidget(self.input_radiobutton_close_details_clicking_somewhere, 2, 1, 1, 1)
        self.gridLayout_3.addLayout(self.gridLayout_13, 0, 0, 2, 2)
        self.input_checkbox_highlight_new_events = QtWidgets.QCheckBox(self.groupbox_detailed_summary_popup)
        self.input_checkbox_highlight_new_events.setObjectName("input_checkbox_highlight_new_events")
        self.gridLayout_3.addWidget(self.input_checkbox_highlight_new_events, 6, 0, 1, 2)
        self.input_checkbox_show_tooltips = QtWidgets.QCheckBox(self.groupbox_detailed_summary_popup)
        self.input_checkbox_show_tooltips.setObjectName("input_checkbox_show_tooltips")
        self.gridLayout_3.addWidget(self.input_checkbox_show_tooltips, 7, 0, 1, 2)
        self.gridLayout_15 = QtWidgets.QGridLayout()
        self.gridLayout_15.setContentsMargins(5, 5, 5, 5)
        self.gridLayout_15.setSpacing(5)
        self.gridLayout_15.setObjectName("gridLayout_15")
        self.input_combobox_default_sort_field = QtWidgets.QComboBox(self.groupbox_detailed_summary_popup)
        self.input_combobox_default_sort_field.setObjectName("input_combobox_default_sort_field")
        self.gridLayout_15.addWidget(self.input_combobox_default_sort_field, 0, 1, 1, 1)
        self.label_default_sort_field = QtWidgets.QLabel(self.groupbox_detailed_summary_popup)
        self.label_default_sort_field.setObjectName("label_default_sort_field")
        self.gridLayout_15.addWidget(self.label_default_sort_field, 0, 0, 1, 1)
        self.label_default_sort_order = QtWidgets.QLabel(self.groupbox_detailed_summary_popup)
        self.label_default_sort_order.setObjectName("label_default_sort_order")
        self.gridLayout_15.addWidget(self.label_default_sort_order, 1, 0, 1, 1)
        self.input_combobox_default_sort_order = QtWidgets.QComboBox(self.groupbox_detailed_summary_popup)
        self.input_combobox_default_sort_order.setObjectName("input_combobox_default_sort_order")
        self.gridLayout_15.addWidget(self.input_combobox_default_sort_order, 1, 1, 1, 1)
        self.gridLayout_3.addLayout(self.gridLayout_15, 8, 0, 1, 1)
        self.gridLayout_2.addWidget(self.groupbox_detailed_summary_popup, 10, 0, 1, 1)
        self.groupbox_appearance = QtWidgets.QGroupBox(self.tab_display)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupbox_appearance.sizePolicy().hasHeightForWidth())
        self.groupbox_appearance.setSizePolicy(sizePolicy)
        self.groupbox_appearance.setObjectName("groupbox_appearance")
        self.gridLayout_17 = QtWidgets.QGridLayout(self.groupbox_appearance)
        self.gridLayout_17.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_17.setSpacing(5)
        self.gridLayout_17.setObjectName("gridLayout_17")
        self.input_radiobutton_icon_in_systray = QtWidgets.QRadioButton(self.groupbox_appearance)
        self.input_radiobutton_icon_in_systray.setObjectName("input_radiobutton_icon_in_systray")
        self.gridLayout_17.addWidget(self.input_radiobutton_icon_in_systray, 1, 0, 1, 1)
        self.input_checkbox_systray_offset_use = QtWidgets.QCheckBox(self.groupbox_appearance)
        self.input_checkbox_systray_offset_use.setObjectName("input_checkbox_systray_offset_use")
        self.gridLayout_17.addWidget(self.input_checkbox_systray_offset_use, 7, 0, 1, 2)
        self.gridLayout_20 = QtWidgets.QGridLayout()
        self.gridLayout_20.setObjectName("gridLayout_20")
        self.label_fullscreen_display = QtWidgets.QLabel(self.groupbox_appearance)
        self.label_fullscreen_display.setObjectName("label_fullscreen_display")
        self.gridLayout_20.addWidget(self.label_fullscreen_display, 1, 0, 1, 1)
        self.label_offset_statuswindow = QtWidgets.QLabel(self.groupbox_appearance)
        self.label_offset_statuswindow.setObjectName("label_offset_statuswindow")
        self.gridLayout_20.addWidget(self.label_offset_statuswindow, 0, 0, 1, 1)
        self.input_spinbox_systray_offset = QtWidgets.QSpinBox(self.groupbox_appearance)
        self.input_spinbox_systray_offset.setObjectName("input_spinbox_systray_offset")
        self.gridLayout_20.addWidget(self.input_spinbox_systray_offset, 0, 1, 1, 1)
        self.input_combobox_fullscreen_display = QtWidgets.QComboBox(self.groupbox_appearance)
        self.input_combobox_fullscreen_display.setObjectName("input_combobox_fullscreen_display")
        self.gridLayout_20.addWidget(self.input_combobox_fullscreen_display, 1, 1, 1, 1)
        self.gridLayout_17.addLayout(self.gridLayout_20, 12, 0, 1, 1)
        self.input_radiobutton_fullscreen = QtWidgets.QRadioButton(self.groupbox_appearance)
        self.input_radiobutton_fullscreen.setObjectName("input_radiobutton_fullscreen")
        self.gridLayout_17.addWidget(self.input_radiobutton_fullscreen, 5, 0, 1, 1)
        self.input_radiobutton_statusbar_floating = QtWidgets.QRadioButton(self.groupbox_appearance)
        self.input_radiobutton_statusbar_floating.setObjectName("input_radiobutton_statusbar_floating")
        self.gridLayout_17.addWidget(self.input_radiobutton_statusbar_floating, 0, 0, 1, 1)
        self.input_radiobutton_windowed = QtWidgets.QRadioButton(self.groupbox_appearance)
        self.input_radiobutton_windowed.setObjectName("input_radiobutton_windowed")
        self.gridLayout_17.addWidget(self.input_radiobutton_windowed, 4, 0, 1, 1)
        self.gridLayout_2.addWidget(self.groupbox_appearance, 2, 0, 1, 1)
        self.groupbox_font = QtWidgets.QGroupBox(self.tab_display)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupbox_font.sizePolicy().hasHeightForWidth())
        self.groupbox_font.setSizePolicy(sizePolicy)
        self.groupbox_font.setObjectName("groupbox_font")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupbox_font)
        self.verticalLayout_3.setContentsMargins(10, 10, 10, 10)
        self.verticalLayout_3.setSpacing(5)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout()
        self.verticalLayout_13.setContentsMargins(5, 5, 5, 5)
        self.verticalLayout_13.setSpacing(5)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.label_font = QtWidgets.QLabel(self.groupbox_font)
        self.label_font.setFrameShape(QtWidgets.QFrame.Box)
        self.label_font.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.label_font.setWordWrap(True)
        self.label_font.setObjectName("label_font")
        self.verticalLayout_13.addWidget(self.label_font)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setContentsMargins(5, 5, 5, 5)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.button_fontchooser = QtWidgets.QPushButton(self.groupbox_font)
        self.button_fontchooser.setObjectName("button_fontchooser")
        self.horizontalLayout_6.addWidget(self.button_fontchooser)
        self.button_default_font = QtWidgets.QPushButton(self.groupbox_font)
        self.button_default_font.setObjectName("button_default_font")
        self.horizontalLayout_6.addWidget(self.button_default_font)
        self.verticalLayout_13.addLayout(self.horizontalLayout_6)
        self.verticalLayout_3.addLayout(self.verticalLayout_13)
        self.gridLayout_2.addWidget(self.groupbox_font, 4, 0, 1, 1)
        self.tabs.addTab(self.tab_display, "")
        self.tab_filters = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tab_filters.sizePolicy().hasHeightForWidth())
        self.tab_filters.setSizePolicy(sizePolicy)
        self.tab_filters.setObjectName("tab_filters")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.tab_filters)
        self.gridLayout_4.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_4.setSpacing(5)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.input_checkbox_re_attempt_enabled = QtWidgets.QCheckBox(self.tab_filters)
        self.input_checkbox_re_attempt_enabled.setObjectName("input_checkbox_re_attempt_enabled")
        self.gridLayout_4.addWidget(self.input_checkbox_re_attempt_enabled, 17, 0, 1, 1)
        self.input_checkbox_re_service_enabled = QtWidgets.QCheckBox(self.tab_filters)
        self.input_checkbox_re_service_enabled.setObjectName("input_checkbox_re_service_enabled")
        self.gridLayout_4.addWidget(self.input_checkbox_re_service_enabled, 8, 0, 1, 1)
        self.layout_re_status_information = QtWidgets.QHBoxLayout()
        self.layout_re_status_information.setContentsMargins(5, 5, 5, 5)
        self.layout_re_status_information.setSpacing(5)
        self.layout_re_status_information.setObjectName("layout_re_status_information")
        self.input_lineedit_re_status_information_pattern = QtWidgets.QLineEdit(self.tab_filters)
        self.input_lineedit_re_status_information_pattern.setObjectName("input_lineedit_re_status_information_pattern")
        self.layout_re_status_information.addWidget(self.input_lineedit_re_status_information_pattern)
        self.input_checkbox_re_status_information_reverse = QtWidgets.QCheckBox(self.tab_filters)
        self.input_checkbox_re_status_information_reverse.setObjectName("input_checkbox_re_status_information_reverse")
        self.layout_re_status_information.addWidget(self.input_checkbox_re_status_information_reverse)
        self.gridLayout_4.addLayout(self.layout_re_status_information, 12, 0, 2, 1)
        spacerItem5 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_4.addItem(spacerItem5, 24, 0, 1, 1)
        self.layout_re_duration = QtWidgets.QHBoxLayout()
        self.layout_re_duration.setContentsMargins(5, 5, 5, 5)
        self.layout_re_duration.setSpacing(5)
        self.layout_re_duration.setObjectName("layout_re_duration")
        self.input_lineedit_re_duration_pattern = QtWidgets.QLineEdit(self.tab_filters)
        self.input_lineedit_re_duration_pattern.setObjectName("input_lineedit_re_duration_pattern")
        self.layout_re_duration.addWidget(self.input_lineedit_re_duration_pattern)
        self.input_checkbox_re_duration_reverse = QtWidgets.QCheckBox(self.tab_filters)
        self.input_checkbox_re_duration_reverse.setObjectName("input_checkbox_re_duration_reverse")
        self.layout_re_duration.addWidget(self.input_checkbox_re_duration_reverse)
        self.gridLayout_4.addLayout(self.layout_re_duration, 15, 0, 1, 1)
        self.input_checkbox_re_status_information_enabled = QtWidgets.QCheckBox(self.tab_filters)
        self.input_checkbox_re_status_information_enabled.setObjectName("input_checkbox_re_status_information_enabled")
        self.gridLayout_4.addWidget(self.input_checkbox_re_status_information_enabled, 11, 0, 1, 1)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setContentsMargins(5, 5, 5, 5)
        self.horizontalLayout_10.setSpacing(5)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.input_lineedit_re_service_pattern = QtWidgets.QLineEdit(self.tab_filters)
        self.input_lineedit_re_service_pattern.setObjectName("input_lineedit_re_service_pattern")
        self.horizontalLayout_10.addWidget(self.input_lineedit_re_service_pattern)
        self.input_checkbox_re_service_reverse = QtWidgets.QCheckBox(self.tab_filters)
        self.input_checkbox_re_service_reverse.setObjectName("input_checkbox_re_service_reverse")
        self.horizontalLayout_10.addWidget(self.input_checkbox_re_service_reverse)
        self.gridLayout_4.addLayout(self.horizontalLayout_10, 9, 0, 2, 1)
        self.input_checkbox_re_groups_enabled = QtWidgets.QCheckBox(self.tab_filters)
        self.input_checkbox_re_groups_enabled.setObjectName("input_checkbox_re_groups_enabled")
        self.gridLayout_4.addWidget(self.input_checkbox_re_groups_enabled, 20, 0, 1, 1)
        self.layout_re_attempt = QtWidgets.QHBoxLayout()
        self.layout_re_attempt.setContentsMargins(5, 5, 5, 5)
        self.layout_re_attempt.setSpacing(5)
        self.layout_re_attempt.setObjectName("layout_re_attempt")
        self.input_lineedit_re_attempt_pattern = QtWidgets.QLineEdit(self.tab_filters)
        self.input_lineedit_re_attempt_pattern.setObjectName("input_lineedit_re_attempt_pattern")
        self.layout_re_attempt.addWidget(self.input_lineedit_re_attempt_pattern)
        self.input_checkbox_re_attempt_reverse = QtWidgets.QCheckBox(self.tab_filters)
        self.input_checkbox_re_attempt_reverse.setObjectName("input_checkbox_re_attempt_reverse")
        self.layout_re_attempt.addWidget(self.input_checkbox_re_attempt_reverse)
        self.gridLayout_4.addLayout(self.layout_re_attempt, 18, 0, 1, 1)
        self.input_checkbox_re_duration_enabled = QtWidgets.QCheckBox(self.tab_filters)
        self.input_checkbox_re_duration_enabled.setObjectName("input_checkbox_re_duration_enabled")
        self.gridLayout_4.addWidget(self.input_checkbox_re_duration_enabled, 14, 0, 1, 1)
        self.layout_re_groups = QtWidgets.QHBoxLayout()
        self.layout_re_groups.setContentsMargins(5, 5, 5, 5)
        self.layout_re_groups.setSpacing(5)
        self.layout_re_groups.setObjectName("layout_re_groups")
        self.input_lineedit_re_groups_pattern = QtWidgets.QLineEdit(self.tab_filters)
        self.input_lineedit_re_groups_pattern.setObjectName("input_lineedit_re_groups_pattern")
        self.layout_re_groups.addWidget(self.input_lineedit_re_groups_pattern)
        self.input_checkbox_re_groups_reverse = QtWidgets.QCheckBox(self.tab_filters)
        self.input_checkbox_re_groups_reverse.setObjectName("input_checkbox_re_groups_reverse")
        self.layout_re_groups.addWidget(self.input_checkbox_re_groups_reverse)
        self.gridLayout_4.addLayout(self.layout_re_groups, 21, 0, 1, 1)
        self.label_python_re = QtWidgets.QLabel(self.tab_filters)
        self.label_python_re.setOpenExternalLinks(True)
        self.label_python_re.setTextInteractionFlags(QtCore.Qt.TextBrowserInteraction)
        self.label_python_re.setObjectName("label_python_re")
        self.gridLayout_4.addWidget(self.label_python_re, 23, 0, 1, 1)
        self.input_checkbox_re_host_enabled = QtWidgets.QCheckBox(self.tab_filters)
        self.input_checkbox_re_host_enabled.setObjectName("input_checkbox_re_host_enabled")
        self.gridLayout_4.addWidget(self.input_checkbox_re_host_enabled, 3, 0, 1, 1)
        self.groupbox_filters = QtWidgets.QGroupBox(self.tab_filters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupbox_filters.sizePolicy().hasHeightForWidth())
        self.groupbox_filters.setSizePolicy(sizePolicy)
        self.groupbox_filters.setObjectName("groupbox_filters")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.groupbox_filters)
        self.gridLayout_5.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_5.setHorizontalSpacing(10)
        self.gridLayout_5.setVerticalSpacing(5)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.input_checkbox_filter_all_down_hosts = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_all_down_hosts.setObjectName("input_checkbox_filter_all_down_hosts")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_all_down_hosts, 0, 0, 1, 1)
        self.input_checkbox_filter_all_unreachable_hosts = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_all_unreachable_hosts.setObjectName("input_checkbox_filter_all_unreachable_hosts")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_all_unreachable_hosts, 1, 0, 1, 1)
        self.input_checkbox_filter_all_unreachable_services = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_all_unreachable_services.setObjectName("input_checkbox_filter_all_unreachable_services")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_all_unreachable_services, 2, 0, 1, 1)
        self.input_checkbox_filter_all_flapping_hosts = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_all_flapping_hosts.setObjectName("input_checkbox_filter_all_flapping_hosts")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_all_flapping_hosts, 3, 0, 1, 1)
        self.input_checkbox_filter_all_critical_services = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_all_critical_services.setObjectName("input_checkbox_filter_all_critical_services")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_all_critical_services, 4, 0, 1, 1)
        self.input_checkbox_filter_acknowledged_hosts_services = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_acknowledged_hosts_services.setObjectName("input_checkbox_filter_acknowledged_hosts_services")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_acknowledged_hosts_services, 0, 1, 1, 1)
        self.input_checkbox_filter_hosts_services_disabled_notifications = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_hosts_services_disabled_notifications.setObjectName("input_checkbox_filter_hosts_services_disabled_notifications")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_hosts_services_disabled_notifications, 1, 1, 1, 1)
        self.input_checkbox_filter_hosts_services_disabled_checks = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_hosts_services_disabled_checks.setObjectName("input_checkbox_filter_hosts_services_disabled_checks")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_hosts_services_disabled_checks, 2, 1, 1, 1)
        self.input_checkbox_filter_hosts_services_maintenance = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_hosts_services_maintenance.setObjectName("input_checkbox_filter_hosts_services_maintenance")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_hosts_services_maintenance, 3, 1, 1, 1)
        self.input_checkbox_filter_services_on_acknowledged_hosts = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_services_on_acknowledged_hosts.setObjectName("input_checkbox_filter_services_on_acknowledged_hosts")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_services_on_acknowledged_hosts, 4, 1, 1, 1)
        self.input_checkbox_filter_services_on_down_hosts = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_services_on_down_hosts.setObjectName("input_checkbox_filter_services_on_down_hosts")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_services_on_down_hosts, 5, 1, 1, 1)
        self.input_checkbox_filter_all_high_services = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_all_high_services.setObjectName("input_checkbox_filter_all_high_services")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_all_high_services, 13, 0, 1, 1)
        self.input_checkbox_filter_all_disaster_services = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_all_disaster_services.setObjectName("input_checkbox_filter_all_disaster_services")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_all_disaster_services, 11, 0, 1, 1)
        self.input_checkbox_filter_all_flapping_services = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_all_flapping_services.setObjectName("input_checkbox_filter_all_flapping_services")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_all_flapping_services, 5, 0, 1, 1)
        self.input_checkbox_filter_all_unknown_services = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_all_unknown_services.setObjectName("input_checkbox_filter_all_unknown_services")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_all_unknown_services, 6, 0, 1, 1)
        self.input_checkbox_filter_all_warning_services = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_all_warning_services.setObjectName("input_checkbox_filter_all_warning_services")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_all_warning_services, 7, 0, 1, 1)
        self.input_checkbox_filter_all_information_services = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_all_information_services.setObjectName("input_checkbox_filter_all_information_services")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_all_information_services, 9, 0, 1, 1)
        self.input_checkbox_filter_all_average_services = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_all_average_services.setObjectName("input_checkbox_filter_all_average_services")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_all_average_services, 10, 0, 1, 1)
        self.input_checkbox_filter_services_on_hosts_in_maintenance = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_services_on_hosts_in_maintenance.setObjectName("input_checkbox_filter_services_on_hosts_in_maintenance")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_services_on_hosts_in_maintenance, 6, 1, 1, 1)
        self.input_checkbox_filter_services_on_unreachable_hosts = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_services_on_unreachable_hosts.setObjectName("input_checkbox_filter_services_on_unreachable_hosts")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_services_on_unreachable_hosts, 7, 1, 1, 1)
        self.input_checkbox_filter_hosts_in_soft_state = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_hosts_in_soft_state.setObjectName("input_checkbox_filter_hosts_in_soft_state")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_hosts_in_soft_state, 9, 1, 1, 1)
        self.input_checkbox_filter_services_in_soft_state = QtWidgets.QCheckBox(self.groupbox_filters)
        self.input_checkbox_filter_services_in_soft_state.setObjectName("input_checkbox_filter_services_in_soft_state")
        self.gridLayout_5.addWidget(self.input_checkbox_filter_services_in_soft_state, 10, 1, 1, 1)
        self.gridLayout_4.addWidget(self.groupbox_filters, 1, 0, 1, 1)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setContentsMargins(5, 5, 5, 5)
        self.horizontalLayout_9.setSpacing(5)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.input_lineedit_re_host_pattern = QtWidgets.QLineEdit(self.tab_filters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.input_lineedit_re_host_pattern.sizePolicy().hasHeightForWidth())
        self.input_lineedit_re_host_pattern.setSizePolicy(sizePolicy)
        self.input_lineedit_re_host_pattern.setObjectName("input_lineedit_re_host_pattern")
        self.horizontalLayout_9.addWidget(self.input_lineedit_re_host_pattern)
        self.input_checkbox_re_host_reverse = QtWidgets.QCheckBox(self.tab_filters)
        self.input_checkbox_re_host_reverse.setObjectName("input_checkbox_re_host_reverse")
        self.horizontalLayout_9.addWidget(self.input_checkbox_re_host_reverse)
        self.gridLayout_4.addLayout(self.horizontalLayout_9, 4, 0, 2, 1)
        self.tabs.addTab(self.tab_filters, "")
        self.tab_actions = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tab_actions.sizePolicy().hasHeightForWidth())
        self.tab_actions.setSizePolicy(sizePolicy)
        self.tab_actions.setObjectName("tab_actions")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.tab_actions)
        self.gridLayout_6.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_6.setSpacing(5)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.list_actions = QtWidgets.QListWidget(self.tab_actions)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.list_actions.sizePolicy().hasHeightForWidth())
        self.list_actions.setSizePolicy(sizePolicy)
        self.list_actions.setMinimumSize(QtCore.QSize(0, 200))
        self.list_actions.setResizeMode(QtWidgets.QListView.Adjust)
        self.list_actions.setObjectName("list_actions")
        self.gridLayout_6.addWidget(self.list_actions, 0, 0, 1, 1)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setContentsMargins(0, 5, 0, 5)
        self.verticalLayout_4.setSpacing(5)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.button_new_action = QtWidgets.QPushButton(self.tab_actions)
        self.button_new_action.setObjectName("button_new_action")
        self.verticalLayout_4.addWidget(self.button_new_action)
        self.button_edit_action = QtWidgets.QPushButton(self.tab_actions)
        self.button_edit_action.setObjectName("button_edit_action")
        self.verticalLayout_4.addWidget(self.button_edit_action)
        self.button_copy_action = QtWidgets.QPushButton(self.tab_actions)
        self.button_copy_action.setObjectName("button_copy_action")
        self.verticalLayout_4.addWidget(self.button_copy_action)
        self.button_delete_action = QtWidgets.QPushButton(self.tab_actions)
        self.button_delete_action.setObjectName("button_delete_action")
        self.verticalLayout_4.addWidget(self.button_delete_action)
        spacerItem6 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem6)
        self.gridLayout_6.addLayout(self.verticalLayout_4, 0, 2, 1, 1)
        self.groupbox_connection_method = QtWidgets.QGroupBox(self.tab_actions)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupbox_connection_method.sizePolicy().hasHeightForWidth())
        self.groupbox_connection_method.setSizePolicy(sizePolicy)
        self.groupbox_connection_method.setObjectName("groupbox_connection_method")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.groupbox_connection_method)
        self.verticalLayout_5.setContentsMargins(10, 10, 10, 10)
        self.verticalLayout_5.setSpacing(5)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.input_radiobutton_connect_by_host = QtWidgets.QRadioButton(self.groupbox_connection_method)
        self.input_radiobutton_connect_by_host.setObjectName("input_radiobutton_connect_by_host")
        self.verticalLayout_5.addWidget(self.input_radiobutton_connect_by_host)
        self.input_radiobutton_connect_by_dns = QtWidgets.QRadioButton(self.groupbox_connection_method)
        self.input_radiobutton_connect_by_dns.setObjectName("input_radiobutton_connect_by_dns")
        self.verticalLayout_5.addWidget(self.input_radiobutton_connect_by_dns)
        self.input_radiobutton_connect_by_ip = QtWidgets.QRadioButton(self.groupbox_connection_method)
        self.input_radiobutton_connect_by_ip.setObjectName("input_radiobutton_connect_by_ip")
        self.verticalLayout_5.addWidget(self.input_radiobutton_connect_by_ip)
        self.gridLayout_6.addWidget(self.groupbox_connection_method, 1, 0, 1, 1)
        spacerItem7 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_6.addItem(spacerItem7, 3, 0, 1, 1)
        self.groupbox_browser = QtWidgets.QGroupBox(self.tab_actions)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupbox_browser.sizePolicy().hasHeightForWidth())
        self.groupbox_browser.setSizePolicy(sizePolicy)
        self.groupbox_browser.setObjectName("groupbox_browser")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.groupbox_browser)
        self.verticalLayout_14.setContentsMargins(10, 10, 10, 10)
        self.verticalLayout_14.setSpacing(5)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.input_radiobutton_use_default_browser = QtWidgets.QRadioButton(self.groupbox_browser)
        self.input_radiobutton_use_default_browser.setObjectName("input_radiobutton_use_default_browser")
        self.verticalLayout_14.addWidget(self.input_radiobutton_use_default_browser)
        self.input_radiobutton_use_custom_browser = QtWidgets.QRadioButton(self.groupbox_browser)
        self.input_radiobutton_use_custom_browser.setObjectName("input_radiobutton_use_custom_browser")
        self.verticalLayout_14.addWidget(self.input_radiobutton_use_custom_browser)
        self.groupbox_custom_browser = QtWidgets.QGroupBox(self.groupbox_browser)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupbox_custom_browser.sizePolicy().hasHeightForWidth())
        self.groupbox_custom_browser.setSizePolicy(sizePolicy)
        self.groupbox_custom_browser.setObjectName("groupbox_custom_browser")
        self.gridLayout_19 = QtWidgets.QGridLayout(self.groupbox_custom_browser)
        self.gridLayout_19.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_19.setSpacing(5)
        self.gridLayout_19.setObjectName("gridLayout_19")
        self.input_lineedit_custom_browser = QtWidgets.QLineEdit(self.groupbox_custom_browser)
        self.input_lineedit_custom_browser.setObjectName("input_lineedit_custom_browser")
        self.gridLayout_19.addWidget(self.input_lineedit_custom_browser, 0, 0, 1, 1)
        self.button_choose_browser = QtWidgets.QPushButton(self.groupbox_custom_browser)
        self.button_choose_browser.setObjectName("button_choose_browser")
        self.gridLayout_19.addWidget(self.button_choose_browser, 0, 1, 1, 1)
        self.verticalLayout_14.addWidget(self.groupbox_custom_browser)
        self.gridLayout_6.addWidget(self.groupbox_browser, 2, 0, 1, 1)
        self.tabs.addTab(self.tab_actions, "")
        self.tab_notifications = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tab_notifications.sizePolicy().hasHeightForWidth())
        self.tab_notifications.setSizePolicy(sizePolicy)
        self.tab_notifications.setObjectName("tab_notifications")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.tab_notifications)
        self.verticalLayout_6.setContentsMargins(10, 10, 10, 10)
        self.verticalLayout_6.setSpacing(5)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.input_checkbox_notification = QtWidgets.QCheckBox(self.tab_notifications)
        self.input_checkbox_notification.setObjectName("input_checkbox_notification")
        self.verticalLayout_6.addWidget(self.input_checkbox_notification)
        self.notification_groupbox = QtWidgets.QGroupBox(self.tab_notifications)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.notification_groupbox.sizePolicy().hasHeightForWidth())
        self.notification_groupbox.setSizePolicy(sizePolicy)
        self.notification_groupbox.setObjectName("notification_groupbox")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.notification_groupbox)
        self.verticalLayout_7.setContentsMargins(10, 10, 10, 10)
        self.verticalLayout_7.setSpacing(5)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.horizontalLayout_notifications = QtWidgets.QHBoxLayout()
        self.horizontalLayout_notifications.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_notifications.setSpacing(5)
        self.horizontalLayout_notifications.setObjectName("horizontalLayout_notifications")
        self.input_checkbox_notify_if_warning = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notify_if_warning.setObjectName("input_checkbox_notify_if_warning")
        self.horizontalLayout_notifications.addWidget(self.input_checkbox_notify_if_warning)
        self.input_checkbox_notify_if_critical = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notify_if_critical.setObjectName("input_checkbox_notify_if_critical")
        self.horizontalLayout_notifications.addWidget(self.input_checkbox_notify_if_critical)
        self.input_checkbox_notify_if_unknown = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notify_if_unknown.setObjectName("input_checkbox_notify_if_unknown")
        self.horizontalLayout_notifications.addWidget(self.input_checkbox_notify_if_unknown)
        self.input_checkbox_notify_if_unreachable = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notify_if_unreachable.setObjectName("input_checkbox_notify_if_unreachable")
        self.horizontalLayout_notifications.addWidget(self.input_checkbox_notify_if_unreachable)
        self.input_checkbox_notify_if_down = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notify_if_down.setObjectName("input_checkbox_notify_if_down")
        self.horizontalLayout_notifications.addWidget(self.input_checkbox_notify_if_down)
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_notifications.addItem(spacerItem8)
        self.verticalLayout_7.addLayout(self.horizontalLayout_notifications)
        self.horizontalLayout_notifications_zabbix = QtWidgets.QHBoxLayout()
        self.horizontalLayout_notifications_zabbix.setObjectName("horizontalLayout_notifications_zabbix")
        self.input_checkbox_notify_if_information = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notify_if_information.setObjectName("input_checkbox_notify_if_information")
        self.horizontalLayout_notifications_zabbix.addWidget(self.input_checkbox_notify_if_information)
        self.input_checkbox_notify_if_disaster = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notify_if_disaster.setObjectName("input_checkbox_notify_if_disaster")
        self.horizontalLayout_notifications_zabbix.addWidget(self.input_checkbox_notify_if_disaster)
        self.input_checkbox_notify_if_average = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notify_if_average.setObjectName("input_checkbox_notify_if_average")
        self.horizontalLayout_notifications_zabbix.addWidget(self.input_checkbox_notify_if_average)
        self.input_checkbox_notify_if_high = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notify_if_high.setObjectName("input_checkbox_notify_if_high")
        self.horizontalLayout_notifications_zabbix.addWidget(self.input_checkbox_notify_if_high)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_notifications_zabbix.addItem(spacerItem9)
        self.verticalLayout_7.addLayout(self.horizontalLayout_notifications_zabbix)
        self.input_checkbox_notification_flashing = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notification_flashing.setObjectName("input_checkbox_notification_flashing")
        self.verticalLayout_7.addWidget(self.input_checkbox_notification_flashing)
        self.input_checkbox_notification_desktop = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notification_desktop.setObjectName("input_checkbox_notification_desktop")
        self.verticalLayout_7.addWidget(self.input_checkbox_notification_desktop)
        self.input_checkbox_notification_sound = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notification_sound.setObjectName("input_checkbox_notification_sound")
        self.verticalLayout_7.addWidget(self.input_checkbox_notification_sound)
        self.notification_sounds_groupbox = QtWidgets.QGroupBox(self.notification_groupbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.notification_sounds_groupbox.sizePolicy().hasHeightForWidth())
        self.notification_sounds_groupbox.setSizePolicy(sizePolicy)
        self.notification_sounds_groupbox.setObjectName("notification_sounds_groupbox")
        self.gridLayout_16 = QtWidgets.QGridLayout(self.notification_sounds_groupbox)
        self.gridLayout_16.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_16.setSpacing(5)
        self.gridLayout_16.setObjectName("gridLayout_16")
        self.notification_custom_sounds_groupbox = QtWidgets.QGroupBox(self.notification_sounds_groupbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.notification_custom_sounds_groupbox.sizePolicy().hasHeightForWidth())
        self.notification_custom_sounds_groupbox.setSizePolicy(sizePolicy)
        self.notification_custom_sounds_groupbox.setObjectName("notification_custom_sounds_groupbox")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.notification_custom_sounds_groupbox)
        self.gridLayout_8.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_8.setSpacing(5)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.button_choose_critical = QtWidgets.QPushButton(self.notification_custom_sounds_groupbox)
        self.button_choose_critical.setObjectName("button_choose_critical")
        self.gridLayout_8.addWidget(self.button_choose_critical, 1, 2, 1, 1)
        self.button_play_warning = QtWidgets.QPushButton(self.notification_custom_sounds_groupbox)
        self.button_play_warning.setObjectName("button_play_warning")
        self.gridLayout_8.addWidget(self.button_play_warning, 0, 3, 1, 1)
        self.label_notification_sound_options_custom_sounds_warning = QtWidgets.QLabel(self.notification_custom_sounds_groupbox)
        self.label_notification_sound_options_custom_sounds_warning.setObjectName("label_notification_sound_options_custom_sounds_warning")
        self.gridLayout_8.addWidget(self.label_notification_sound_options_custom_sounds_warning, 0, 0, 1, 1)
        self.label_notification_sound_options_custom_sounds_critical = QtWidgets.QLabel(self.notification_custom_sounds_groupbox)
        self.label_notification_sound_options_custom_sounds_critical.setObjectName("label_notification_sound_options_custom_sounds_critical")
        self.gridLayout_8.addWidget(self.label_notification_sound_options_custom_sounds_critical, 1, 0, 1, 1)
        self.button_choose_down = QtWidgets.QPushButton(self.notification_custom_sounds_groupbox)
        self.button_choose_down.setObjectName("button_choose_down")
        self.gridLayout_8.addWidget(self.button_choose_down, 2, 2, 1, 1)
        self.button_choose_warning = QtWidgets.QPushButton(self.notification_custom_sounds_groupbox)
        self.button_choose_warning.setObjectName("button_choose_warning")
        self.gridLayout_8.addWidget(self.button_choose_warning, 0, 2, 1, 1)
        self.button_play_critical = QtWidgets.QPushButton(self.notification_custom_sounds_groupbox)
        self.button_play_critical.setObjectName("button_play_critical")
        self.gridLayout_8.addWidget(self.button_play_critical, 1, 3, 1, 1)
        self.label_notification_sound_options_custom_sounds_down = QtWidgets.QLabel(self.notification_custom_sounds_groupbox)
        self.label_notification_sound_options_custom_sounds_down.setObjectName("label_notification_sound_options_custom_sounds_down")
        self.gridLayout_8.addWidget(self.label_notification_sound_options_custom_sounds_down, 2, 0, 1, 1)
        self.button_play_down = QtWidgets.QPushButton(self.notification_custom_sounds_groupbox)
        self.button_play_down.setObjectName("button_play_down")
        self.gridLayout_8.addWidget(self.button_play_down, 2, 3, 1, 1)
        self.input_lineedit_notification_custom_sound_warning = QtWidgets.QLineEdit(self.notification_custom_sounds_groupbox)
        self.input_lineedit_notification_custom_sound_warning.setObjectName("input_lineedit_notification_custom_sound_warning")
        self.gridLayout_8.addWidget(self.input_lineedit_notification_custom_sound_warning, 0, 1, 1, 1)
        self.input_lineedit_notification_custom_sound_critical = QtWidgets.QLineEdit(self.notification_custom_sounds_groupbox)
        self.input_lineedit_notification_custom_sound_critical.setObjectName("input_lineedit_notification_custom_sound_critical")
        self.gridLayout_8.addWidget(self.input_lineedit_notification_custom_sound_critical, 1, 1, 1, 1)
        self.input_lineedit_notification_custom_sound_down = QtWidgets.QLineEdit(self.notification_custom_sounds_groupbox)
        self.input_lineedit_notification_custom_sound_down.setObjectName("input_lineedit_notification_custom_sound_down")
        self.gridLayout_8.addWidget(self.input_lineedit_notification_custom_sound_down, 2, 1, 1, 1)
        self.gridLayout_16.addWidget(self.notification_custom_sounds_groupbox, 3, 0, 1, 2)
        self.input_checkbox_notification_sound_repeat = QtWidgets.QCheckBox(self.notification_sounds_groupbox)
        self.input_checkbox_notification_sound_repeat.setObjectName("input_checkbox_notification_sound_repeat")
        self.gridLayout_16.addWidget(self.input_checkbox_notification_sound_repeat, 0, 0, 1, 2)
        self.input_radiobutton_notification_default_sound = QtWidgets.QRadioButton(self.notification_sounds_groupbox)
        self.input_radiobutton_notification_default_sound.setObjectName("input_radiobutton_notification_default_sound")
        self.gridLayout_16.addWidget(self.input_radiobutton_notification_default_sound, 1, 0, 1, 2)
        self.input_radiobutton_notification_custom_sound = QtWidgets.QRadioButton(self.notification_sounds_groupbox)
        self.input_radiobutton_notification_custom_sound.setObjectName("input_radiobutton_notification_custom_sound")
        self.gridLayout_16.addWidget(self.input_radiobutton_notification_custom_sound, 2, 0, 1, 2)
        self.verticalLayout_7.addWidget(self.notification_sounds_groupbox)
        self.input_checkbox_notification_actions = QtWidgets.QCheckBox(self.notification_groupbox)
        self.input_checkbox_notification_actions.setObjectName("input_checkbox_notification_actions")
        self.verticalLayout_7.addWidget(self.input_checkbox_notification_actions)
        self.notification_actions_groupbox = QtWidgets.QGroupBox(self.notification_groupbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.notification_actions_groupbox.sizePolicy().hasHeightForWidth())
        self.notification_actions_groupbox.setSizePolicy(sizePolicy)
        self.notification_actions_groupbox.setObjectName("notification_actions_groupbox")
        self.gridLayout_11 = QtWidgets.QGridLayout(self.notification_actions_groupbox)
        self.gridLayout_11.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_11.setSpacing(5)
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.input_lineedit_notification_action_ok_string = QtWidgets.QLineEdit(self.notification_actions_groupbox)
        self.input_lineedit_notification_action_ok_string.setObjectName("input_lineedit_notification_action_ok_string")
        self.gridLayout_11.addWidget(self.input_lineedit_notification_action_ok_string, 3, 2, 1, 1)
        self.input_checkbox_notification_action_critical = QtWidgets.QCheckBox(self.notification_actions_groupbox)
        self.input_checkbox_notification_action_critical.setObjectName("input_checkbox_notification_action_critical")
        self.gridLayout_11.addWidget(self.input_checkbox_notification_action_critical, 1, 0, 1, 1)
        self.input_checkbox_notification_action_down = QtWidgets.QCheckBox(self.notification_actions_groupbox)
        self.input_checkbox_notification_action_down.setObjectName("input_checkbox_notification_action_down")
        self.gridLayout_11.addWidget(self.input_checkbox_notification_action_down, 2, 0, 1, 1)
        self.input_checkbox_notification_action_ok = QtWidgets.QCheckBox(self.notification_actions_groupbox)
        self.input_checkbox_notification_action_ok.setObjectName("input_checkbox_notification_action_ok")
        self.gridLayout_11.addWidget(self.input_checkbox_notification_action_ok, 3, 0, 1, 1)
        self.input_checkbox_notification_action_warning = QtWidgets.QCheckBox(self.notification_actions_groupbox)
        self.input_checkbox_notification_action_warning.setObjectName("input_checkbox_notification_action_warning")
        self.gridLayout_11.addWidget(self.input_checkbox_notification_action_warning, 0, 0, 1, 1)
        self.input_lineedit_notification_action_down_string = QtWidgets.QLineEdit(self.notification_actions_groupbox)
        self.input_lineedit_notification_action_down_string.setObjectName("input_lineedit_notification_action_down_string")
        self.gridLayout_11.addWidget(self.input_lineedit_notification_action_down_string, 2, 2, 1, 1)
        self.input_checkbox_notification_custom_action = QtWidgets.QCheckBox(self.notification_actions_groupbox)
        self.input_checkbox_notification_custom_action.setObjectName("input_checkbox_notification_custom_action")
        self.gridLayout_11.addWidget(self.input_checkbox_notification_custom_action, 4, 0, 1, 3)
        self.notification_custom_action_groupbox = QtWidgets.QGroupBox(self.notification_actions_groupbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.notification_custom_action_groupbox.sizePolicy().hasHeightForWidth())
        self.notification_custom_action_groupbox.setSizePolicy(sizePolicy)
        self.notification_custom_action_groupbox.setObjectName("notification_custom_action_groupbox")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.notification_custom_action_groupbox)
        self.gridLayout_7.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_7.setSpacing(5)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.label_notification_custom_action_string = QtWidgets.QLabel(self.notification_custom_action_groupbox)
        self.label_notification_custom_action_string.setObjectName("label_notification_custom_action_string")
        self.gridLayout_7.addWidget(self.label_notification_custom_action_string, 1, 0, 1, 1)
        self.label_notification_custom_action_separator = QtWidgets.QLabel(self.notification_custom_action_groupbox)
        self.label_notification_custom_action_separator.setObjectName("label_notification_custom_action_separator")
        self.gridLayout_7.addWidget(self.label_notification_custom_action_separator, 4, 0, 1, 1)
        self.input_lineedit_notification_custom_action_separator = QtWidgets.QLineEdit(self.notification_custom_action_groupbox)
        self.input_lineedit_notification_custom_action_separator.setObjectName("input_lineedit_notification_custom_action_separator")
        self.gridLayout_7.addWidget(self.input_lineedit_notification_custom_action_separator, 4, 3, 1, 1)
        self.input_checkbox_notification_custom_action_single = QtWidgets.QCheckBox(self.notification_custom_action_groupbox)
        self.input_checkbox_notification_custom_action_single.setObjectName("input_checkbox_notification_custom_action_single")
        self.gridLayout_7.addWidget(self.input_checkbox_notification_custom_action_single, 2, 3, 1, 1)
        self.input_lineedit_notification_custom_action_string = QtWidgets.QLineEdit(self.notification_custom_action_groupbox)
        self.input_lineedit_notification_custom_action_string.setObjectName("input_lineedit_notification_custom_action_string")
        self.gridLayout_7.addWidget(self.input_lineedit_notification_custom_action_string, 1, 3, 1, 1)
        self.gridLayout_11.addWidget(self.notification_custom_action_groupbox, 6, 0, 1, 3)
        self.input_lineedit_notification_action_critical_string = QtWidgets.QLineEdit(self.notification_actions_groupbox)
        self.input_lineedit_notification_action_critical_string.setObjectName("input_lineedit_notification_action_critical_string")
        self.gridLayout_11.addWidget(self.input_lineedit_notification_action_critical_string, 1, 2, 1, 1)
        self.input_lineedit_notification_action_warning_string = QtWidgets.QLineEdit(self.notification_actions_groupbox)
        self.input_lineedit_notification_action_warning_string.setObjectName("input_lineedit_notification_action_warning_string")
        self.gridLayout_11.addWidget(self.input_lineedit_notification_action_warning_string, 0, 2, 1, 1)
        self.verticalLayout_7.addWidget(self.notification_actions_groupbox)
        self.verticalLayout_6.addWidget(self.notification_groupbox)
        spacerItem10 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_6.addItem(spacerItem10)
        self.tabs.addTab(self.tab_notifications, "")
        self.tab_colors = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tab_colors.sizePolicy().hasHeightForWidth())
        self.tab_colors.setSizePolicy(sizePolicy)
        self.tab_colors.setObjectName("tab_colors")
        self.gridLayout_12 = QtWidgets.QGridLayout(self.tab_colors)
        self.gridLayout_12.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_12.setSpacing(5)
        self.gridLayout_12.setObjectName("gridLayout_12")
        spacerItem11 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_12.addItem(spacerItem11, 12, 1, 1, 1)
        self.label_colors = QtWidgets.QLabel(self.tab_colors)
        self.label_colors.setObjectName("label_colors")
        self.gridLayout_12.addWidget(self.label_colors, 0, 0, 1, 3)
        self.states_groupbox = QtWidgets.QGroupBox(self.tab_colors)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.states_groupbox.sizePolicy().hasHeightForWidth())
        self.states_groupbox.setSizePolicy(sizePolicy)
        self.states_groupbox.setObjectName("states_groupbox")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.states_groupbox)
        self.verticalLayout_11.setContentsMargins(10, 10, 10, 5)
        self.verticalLayout_11.setSpacing(5)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.label_color_ok = QtWidgets.QLabel(self.states_groupbox)
        self.label_color_ok.setObjectName("label_color_ok")
        self.verticalLayout_11.addWidget(self.label_color_ok)
        self.label_color_information = QtWidgets.QLabel(self.states_groupbox)
        self.label_color_information.setObjectName("label_color_information")
        self.verticalLayout_11.addWidget(self.label_color_information)
        self.label_color_warning = QtWidgets.QLabel(self.states_groupbox)
        self.label_color_warning.setObjectName("label_color_warning")
        self.verticalLayout_11.addWidget(self.label_color_warning)
        self.label_color_average = QtWidgets.QLabel(self.states_groupbox)
        self.label_color_average.setObjectName("label_color_average")
        self.verticalLayout_11.addWidget(self.label_color_average)
        self.label_color_high = QtWidgets.QLabel(self.states_groupbox)
        self.label_color_high.setObjectName("label_color_high")
        self.verticalLayout_11.addWidget(self.label_color_high)
        self.label_color_critical = QtWidgets.QLabel(self.states_groupbox)
        self.label_color_critical.setObjectName("label_color_critical")
        self.verticalLayout_11.addWidget(self.label_color_critical)
        self.label_color_disaster = QtWidgets.QLabel(self.states_groupbox)
        self.label_color_disaster.setObjectName("label_color_disaster")
        self.verticalLayout_11.addWidget(self.label_color_disaster)
        self.label_color_unknown = QtWidgets.QLabel(self.states_groupbox)
        self.label_color_unknown.setObjectName("label_color_unknown")
        self.verticalLayout_11.addWidget(self.label_color_unknown)
        self.label_color_unreachable = QtWidgets.QLabel(self.states_groupbox)
        self.label_color_unreachable.setObjectName("label_color_unreachable")
        self.verticalLayout_11.addWidget(self.label_color_unreachable)
        self.label_color_down = QtWidgets.QLabel(self.states_groupbox)
        self.label_color_down.setObjectName("label_color_down")
        self.verticalLayout_11.addWidget(self.label_color_down)
        self.label_color_error = QtWidgets.QLabel(self.states_groupbox)
        self.label_color_error.setObjectName("label_color_error")
        self.verticalLayout_11.addWidget(self.label_color_error)
        self.gridLayout_12.addWidget(self.states_groupbox, 1, 0, 8, 1)
        self.text_groupbox = QtWidgets.QGroupBox(self.tab_colors)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.text_groupbox.sizePolicy().hasHeightForWidth())
        self.text_groupbox.setSizePolicy(sizePolicy)
        self.text_groupbox.setObjectName("text_groupbox")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.text_groupbox)
        self.verticalLayout_8.setContentsMargins(10, 10, 10, 5)
        self.verticalLayout_8.setSpacing(5)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.input_button_color_ok_text = QtWidgets.QPushButton(self.text_groupbox)
        self.input_button_color_ok_text.setText("")
        self.input_button_color_ok_text.setObjectName("input_button_color_ok_text")
        self.verticalLayout_8.addWidget(self.input_button_color_ok_text)
        self.input_button_color_information_text = QtWidgets.QPushButton(self.text_groupbox)
        self.input_button_color_information_text.setText("")
        self.input_button_color_information_text.setObjectName("input_button_color_information_text")
        self.verticalLayout_8.addWidget(self.input_button_color_information_text)
        self.input_button_color_warning_text = QtWidgets.QPushButton(self.text_groupbox)
        self.input_button_color_warning_text.setText("")
        self.input_button_color_warning_text.setObjectName("input_button_color_warning_text")
        self.verticalLayout_8.addWidget(self.input_button_color_warning_text)
        self.input_button_color_average_text = QtWidgets.QPushButton(self.text_groupbox)
        self.input_button_color_average_text.setText("")
        self.input_button_color_average_text.setObjectName("input_button_color_average_text")
        self.verticalLayout_8.addWidget(self.input_button_color_average_text)
        self.input_button_color_high_text = QtWidgets.QPushButton(self.text_groupbox)
        self.input_button_color_high_text.setText("")
        self.input_button_color_high_text.setObjectName("input_button_color_high_text")
        self.verticalLayout_8.addWidget(self.input_button_color_high_text)
        self.input_button_color_critical_text = QtWidgets.QPushButton(self.text_groupbox)
        self.input_button_color_critical_text.setText("")
        self.input_button_color_critical_text.setObjectName("input_button_color_critical_text")
        self.verticalLayout_8.addWidget(self.input_button_color_critical_text)
        self.input_button_color_disaster_text = QtWidgets.QPushButton(self.text_groupbox)
        self.input_button_color_disaster_text.setText("")
        self.input_button_color_disaster_text.setObjectName("input_button_color_disaster_text")
        self.verticalLayout_8.addWidget(self.input_button_color_disaster_text)
        self.input_button_color_unknown_text = QtWidgets.QPushButton(self.text_groupbox)
        self.input_button_color_unknown_text.setText("")
        self.input_button_color_unknown_text.setObjectName("input_button_color_unknown_text")
        self.verticalLayout_8.addWidget(self.input_button_color_unknown_text)
        self.input_button_color_unreachable_text = QtWidgets.QPushButton(self.text_groupbox)
        self.input_button_color_unreachable_text.setText("")
        self.input_button_color_unreachable_text.setObjectName("input_button_color_unreachable_text")
        self.verticalLayout_8.addWidget(self.input_button_color_unreachable_text)
        self.input_button_color_down_text = QtWidgets.QPushButton(self.text_groupbox)
        self.input_button_color_down_text.setText("")
        self.input_button_color_down_text.setObjectName("input_button_color_down_text")
        self.verticalLayout_8.addWidget(self.input_button_color_down_text)
        self.input_button_color_error_text = QtWidgets.QPushButton(self.text_groupbox)
        self.input_button_color_error_text.setText("")
        self.input_button_color_error_text.setObjectName("input_button_color_error_text")
        self.verticalLayout_8.addWidget(self.input_button_color_error_text)
        self.gridLayout_12.addWidget(self.text_groupbox, 1, 1, 8, 1)
        self.background_groupbox = QtWidgets.QGroupBox(self.tab_colors)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.background_groupbox.sizePolicy().hasHeightForWidth())
        self.background_groupbox.setSizePolicy(sizePolicy)
        self.background_groupbox.setObjectName("background_groupbox")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.background_groupbox)
        self.verticalLayout_12.setContentsMargins(10, 5, 10, 10)
        self.verticalLayout_12.setSpacing(5)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.input_button_color_ok_background = QtWidgets.QPushButton(self.background_groupbox)
        self.input_button_color_ok_background.setText("")
        self.input_button_color_ok_background.setObjectName("input_button_color_ok_background")
        self.verticalLayout_12.addWidget(self.input_button_color_ok_background)
        self.input_button_color_information_background = QtWidgets.QPushButton(self.background_groupbox)
        self.input_button_color_information_background.setText("")
        self.input_button_color_information_background.setObjectName("input_button_color_information_background")
        self.verticalLayout_12.addWidget(self.input_button_color_information_background)
        self.input_button_color_warning_background = QtWidgets.QPushButton(self.background_groupbox)
        self.input_button_color_warning_background.setText("")
        self.input_button_color_warning_background.setObjectName("input_button_color_warning_background")
        self.verticalLayout_12.addWidget(self.input_button_color_warning_background)
        self.input_button_color_average_background = QtWidgets.QPushButton(self.background_groupbox)
        self.input_button_color_average_background.setText("")
        self.input_button_color_average_background.setObjectName("input_button_color_average_background")
        self.verticalLayout_12.addWidget(self.input_button_color_average_background)
        self.input_button_color_high_background = QtWidgets.QPushButton(self.background_groupbox)
        self.input_button_color_high_background.setText("")
        self.input_button_color_high_background.setObjectName("input_button_color_high_background")
        self.verticalLayout_12.addWidget(self.input_button_color_high_background)
        self.input_button_color_critical_background = QtWidgets.QPushButton(self.background_groupbox)
        self.input_button_color_critical_background.setText("")
        self.input_button_color_critical_background.setObjectName("input_button_color_critical_background")
        self.verticalLayout_12.addWidget(self.input_button_color_critical_background)
        self.input_button_color_disaster_background = QtWidgets.QPushButton(self.background_groupbox)
        self.input_button_color_disaster_background.setText("")
        self.input_button_color_disaster_background.setObjectName("input_button_color_disaster_background")
        self.verticalLayout_12.addWidget(self.input_button_color_disaster_background)
        self.input_button_color_unknown_background = QtWidgets.QPushButton(self.background_groupbox)
        self.input_button_color_unknown_background.setText("")
        self.input_button_color_unknown_background.setObjectName("input_button_color_unknown_background")
        self.verticalLayout_12.addWidget(self.input_button_color_unknown_background)
        self.input_button_color_unreachable_background = QtWidgets.QPushButton(self.background_groupbox)
        self.input_button_color_unreachable_background.setText("")
        self.input_button_color_unreachable_background.setObjectName("input_button_color_unreachable_background")
        self.verticalLayout_12.addWidget(self.input_button_color_unreachable_background)
        self.input_button_color_down_background = QtWidgets.QPushButton(self.background_groupbox)
        self.input_button_color_down_background.setText("")
        self.input_button_color_down_background.setObjectName("input_button_color_down_background")
        self.verticalLayout_12.addWidget(self.input_button_color_down_background)
        self.input_button_color_error_background = QtWidgets.QPushButton(self.background_groupbox)
        self.input_button_color_error_background.setText("")
        self.input_button_color_error_background.setObjectName("input_button_color_error_background")
        self.verticalLayout_12.addWidget(self.input_button_color_error_background)
        self.gridLayout_12.addWidget(self.background_groupbox, 1, 2, 8, 1)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setContentsMargins(5, 5, 5, 5)
        self.horizontalLayout_12.setSpacing(5)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.button_colors_reset = QtWidgets.QPushButton(self.tab_colors)
        self.button_colors_reset.setObjectName("button_colors_reset")
        self.horizontalLayout_12.addWidget(self.button_colors_reset)
        self.button_colors_defaults = QtWidgets.QPushButton(self.tab_colors)
        self.button_colors_defaults.setObjectName("button_colors_defaults")
        self.horizontalLayout_12.addWidget(self.button_colors_defaults)
        self.gridLayout_12.addLayout(self.horizontalLayout_12, 10, 1, 1, 2)
        self.groupBox_color_grid = QtWidgets.QGroupBox(self.tab_colors)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_color_grid.sizePolicy().hasHeightForWidth())
        self.groupBox_color_grid.setSizePolicy(sizePolicy)
        self.groupBox_color_grid.setObjectName("groupBox_color_grid")
        self.gridLayout_18 = QtWidgets.QGridLayout(self.groupBox_color_grid)
        self.gridLayout_18.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_18.setSpacing(5)
        self.gridLayout_18.setObjectName("gridLayout_18")
        self.input_checkbox_show_grid = QtWidgets.QCheckBox(self.groupBox_color_grid)
        self.input_checkbox_show_grid.setObjectName("input_checkbox_show_grid")
        self.gridLayout_18.addWidget(self.input_checkbox_show_grid, 0, 0, 1, 1)
        self.input_checkbox_grid_use_custom_intensity = QtWidgets.QCheckBox(self.groupBox_color_grid)
        self.input_checkbox_grid_use_custom_intensity.setEnabled(True)
        self.input_checkbox_grid_use_custom_intensity.setObjectName("input_checkbox_grid_use_custom_intensity")
        self.gridLayout_18.addWidget(self.input_checkbox_grid_use_custom_intensity, 1, 0, 1, 1)
        self.input_slider_grid_alternation_intensity = QtWidgets.QSlider(self.groupBox_color_grid)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.input_slider_grid_alternation_intensity.sizePolicy().hasHeightForWidth())
        self.input_slider_grid_alternation_intensity.setSizePolicy(sizePolicy)
        self.input_slider_grid_alternation_intensity.setMaximum(50)
        self.input_slider_grid_alternation_intensity.setOrientation(QtCore.Qt.Horizontal)
        self.input_slider_grid_alternation_intensity.setObjectName("input_slider_grid_alternation_intensity")
        self.gridLayout_18.addWidget(self.input_slider_grid_alternation_intensity, 2, 0, 1, 1)
        self.vbox_alternation_intensity_labels = QtWidgets.QVBoxLayout()
        self.vbox_alternation_intensity_labels.setContentsMargins(5, 5, 5, 5)
        self.vbox_alternation_intensity_labels.setSpacing(0)
        self.vbox_alternation_intensity_labels.setObjectName("vbox_alternation_intensity_labels")
        self.label_intensity_information_0 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_information_0.setAutoFillBackground(True)
        self.label_intensity_information_0.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_information_0.setObjectName("label_intensity_information_0")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_information_0)
        self.label_intensity_information_1 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_information_1.setAutoFillBackground(True)
        self.label_intensity_information_1.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_information_1.setObjectName("label_intensity_information_1")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_information_1)
        self.label_intensity_warning_0 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_warning_0.setAutoFillBackground(True)
        self.label_intensity_warning_0.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_warning_0.setObjectName("label_intensity_warning_0")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_warning_0)
        self.label_intensity_warning_1 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_warning_1.setAutoFillBackground(True)
        self.label_intensity_warning_1.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_warning_1.setObjectName("label_intensity_warning_1")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_warning_1)
        self.label_intensity_average_0 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_average_0.setAutoFillBackground(True)
        self.label_intensity_average_0.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_average_0.setObjectName("label_intensity_average_0")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_average_0)
        self.label_intensity_average_1 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_average_1.setAutoFillBackground(True)
        self.label_intensity_average_1.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_average_1.setObjectName("label_intensity_average_1")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_average_1)
        self.label_intensity_high_0 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_high_0.setAutoFillBackground(True)
        self.label_intensity_high_0.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_high_0.setObjectName("label_intensity_high_0")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_high_0)
        self.label_intensity_high_1 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_high_1.setAutoFillBackground(True)
        self.label_intensity_high_1.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_high_1.setObjectName("label_intensity_high_1")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_high_1)
        self.label_intensity_critical_0 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_critical_0.setAutoFillBackground(True)
        self.label_intensity_critical_0.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_critical_0.setObjectName("label_intensity_critical_0")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_critical_0)
        self.label_intensity_critical_1 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_critical_1.setAutoFillBackground(True)
        self.label_intensity_critical_1.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_critical_1.setObjectName("label_intensity_critical_1")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_critical_1)
        self.label_intensity_disaster_0 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_disaster_0.setAutoFillBackground(True)
        self.label_intensity_disaster_0.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_disaster_0.setObjectName("label_intensity_disaster_0")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_disaster_0)
        self.label_intensity_disaster_1 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_disaster_1.setAutoFillBackground(True)
        self.label_intensity_disaster_1.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_disaster_1.setObjectName("label_intensity_disaster_1")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_disaster_1)
        self.label_intensity_unknown_0 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_unknown_0.setAutoFillBackground(True)
        self.label_intensity_unknown_0.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_unknown_0.setObjectName("label_intensity_unknown_0")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_unknown_0)
        self.label_intensity_unknown_1 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_unknown_1.setAutoFillBackground(True)
        self.label_intensity_unknown_1.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_unknown_1.setObjectName("label_intensity_unknown_1")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_unknown_1)
        self.label_intensity_unreachable_0 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_unreachable_0.setAutoFillBackground(True)
        self.label_intensity_unreachable_0.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_unreachable_0.setObjectName("label_intensity_unreachable_0")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_unreachable_0)
        self.label_intensity_unreachable_1 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_unreachable_1.setAutoFillBackground(True)
        self.label_intensity_unreachable_1.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_unreachable_1.setObjectName("label_intensity_unreachable_1")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_unreachable_1)
        self.label_intensity_down_0 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_down_0.setAutoFillBackground(True)
        self.label_intensity_down_0.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_down_0.setObjectName("label_intensity_down_0")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_down_0)
        self.label_intensity_down_1 = QtWidgets.QLabel(self.groupBox_color_grid)
        self.label_intensity_down_1.setAutoFillBackground(True)
        self.label_intensity_down_1.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_intensity_down_1.setObjectName("label_intensity_down_1")
        self.vbox_alternation_intensity_labels.addWidget(self.label_intensity_down_1)
        self.gridLayout_18.addLayout(self.vbox_alternation_intensity_labels, 2, 1, 1, 1)
        self.gridLayout_12.addWidget(self.groupBox_color_grid, 11, 0, 1, 3)
        self.tabs.addTab(self.tab_colors, "")
        self.tab_defaults = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tab_defaults.sizePolicy().hasHeightForWidth())
        self.tab_defaults.setSizePolicy(sizePolicy)
        self.tab_defaults.setObjectName("tab_defaults")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.tab_defaults)
        self.verticalLayout_9.setContentsMargins(10, 10, 10, 10)
        self.verticalLayout_9.setSpacing(5)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.label_defaults = QtWidgets.QLabel(self.tab_defaults)
        self.label_defaults.setObjectName("label_defaults")
        self.verticalLayout_9.addWidget(self.label_defaults)
        self.label_defaults_acknowledge = QtWidgets.QGroupBox(self.tab_defaults)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_defaults_acknowledge.sizePolicy().hasHeightForWidth())
        self.label_defaults_acknowledge.setSizePolicy(sizePolicy)
        self.label_defaults_acknowledge.setObjectName("label_defaults_acknowledge")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.label_defaults_acknowledge)
        self.verticalLayout_10.setContentsMargins(10, 10, 10, 10)
        self.verticalLayout_10.setSpacing(5)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.input_checkbox_defaults_acknowledge_sticky = QtWidgets.QCheckBox(self.label_defaults_acknowledge)
        self.input_checkbox_defaults_acknowledge_sticky.setObjectName("input_checkbox_defaults_acknowledge_sticky")
        self.verticalLayout_10.addWidget(self.input_checkbox_defaults_acknowledge_sticky)
        self.input_checkbox_defaults_acknowledge_send_notification = QtWidgets.QCheckBox(self.label_defaults_acknowledge)
        self.input_checkbox_defaults_acknowledge_send_notification.setObjectName("input_checkbox_defaults_acknowledge_send_notification")
        self.verticalLayout_10.addWidget(self.input_checkbox_defaults_acknowledge_send_notification)
        self.input_checkbox_defaults_acknowledge_persistent_comment = QtWidgets.QCheckBox(self.label_defaults_acknowledge)
        self.input_checkbox_defaults_acknowledge_persistent_comment.setObjectName("input_checkbox_defaults_acknowledge_persistent_comment")
        self.verticalLayout_10.addWidget(self.input_checkbox_defaults_acknowledge_persistent_comment)
        self.input_checkbox_defaults_acknowledge_all_services = QtWidgets.QCheckBox(self.label_defaults_acknowledge)
        self.input_checkbox_defaults_acknowledge_all_services.setObjectName("input_checkbox_defaults_acknowledge_all_services")
        self.verticalLayout_10.addWidget(self.input_checkbox_defaults_acknowledge_all_services)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setContentsMargins(-1, 5, 5, 5)
        self.horizontalLayout_13.setSpacing(5)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.label_defaults_acknowledge_comment = QtWidgets.QLabel(self.label_defaults_acknowledge)
        self.label_defaults_acknowledge_comment.setObjectName("label_defaults_acknowledge_comment")
        self.horizontalLayout_13.addWidget(self.label_defaults_acknowledge_comment)
        self.input_lineedit_defaults_acknowledge_comment = QtWidgets.QLineEdit(self.label_defaults_acknowledge)
        self.input_lineedit_defaults_acknowledge_comment.setObjectName("input_lineedit_defaults_acknowledge_comment")
        self.horizontalLayout_13.addWidget(self.input_lineedit_defaults_acknowledge_comment)
        self.verticalLayout_10.addLayout(self.horizontalLayout_13)
        self.input_checkbox_defaults_acknowledge_expire = QtWidgets.QCheckBox(self.label_defaults_acknowledge)
        self.input_checkbox_defaults_acknowledge_expire.setEnabled(True)
        self.input_checkbox_defaults_acknowledge_expire.setObjectName("input_checkbox_defaults_acknowledge_expire")
        self.verticalLayout_10.addWidget(self.input_checkbox_defaults_acknowledge_expire)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setContentsMargins(0, 5, 5, 5)
        self.horizontalLayout_7.setSpacing(5)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_expire_in = QtWidgets.QLabel(self.label_defaults_acknowledge)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_expire_in.sizePolicy().hasHeightForWidth())
        self.label_expire_in.setSizePolicy(sizePolicy)
        self.label_expire_in.setObjectName("label_expire_in")
        self.horizontalLayout_7.addWidget(self.label_expire_in)
        self.input_spinbox_defaults_acknowledge_expire_duration_hours = QtWidgets.QSpinBox(self.label_defaults_acknowledge)
        self.input_spinbox_defaults_acknowledge_expire_duration_hours.setObjectName("input_spinbox_defaults_acknowledge_expire_duration_hours")
        self.horizontalLayout_7.addWidget(self.input_spinbox_defaults_acknowledge_expire_duration_hours)
        self.label_expire_in_hours = QtWidgets.QLabel(self.label_defaults_acknowledge)
        self.label_expire_in_hours.setObjectName("label_expire_in_hours")
        self.horizontalLayout_7.addWidget(self.label_expire_in_hours)
        self.input_spinbox_defaults_acknowledge_expire_duration_minutes = QtWidgets.QSpinBox(self.label_defaults_acknowledge)
        self.input_spinbox_defaults_acknowledge_expire_duration_minutes.setObjectName("input_spinbox_defaults_acknowledge_expire_duration_minutes")
        self.horizontalLayout_7.addWidget(self.input_spinbox_defaults_acknowledge_expire_duration_minutes)
        self.label_expire_in_minutes = QtWidgets.QLabel(self.label_defaults_acknowledge)
        self.label_expire_in_minutes.setObjectName("label_expire_in_minutes")
        self.horizontalLayout_7.addWidget(self.label_expire_in_minutes)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem12)
        self.verticalLayout_10.addLayout(self.horizontalLayout_7)
        self.verticalLayout_9.addWidget(self.label_defaults_acknowledge)
        self.label_defaults_downtime = QtWidgets.QGroupBox(self.tab_defaults)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_defaults_downtime.sizePolicy().hasHeightForWidth())
        self.label_defaults_downtime.setSizePolicy(sizePolicy)
        self.label_defaults_downtime.setObjectName("label_defaults_downtime")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.label_defaults_downtime)
        self.gridLayout_10.setContentsMargins(10, 10, 10, 10)
        self.gridLayout_10.setSpacing(5)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.label_defaults_downtime_comment = QtWidgets.QLabel(self.label_defaults_downtime)
        self.label_defaults_downtime_comment.setObjectName("label_defaults_downtime_comment")
        self.gridLayout_10.addWidget(self.label_defaults_downtime_comment, 3, 0, 1, 1)
        self.label_defaults_duration_comment = QtWidgets.QLabel(self.label_defaults_downtime)
        self.label_defaults_duration_comment.setObjectName("label_defaults_duration_comment")
        self.gridLayout_10.addWidget(self.label_defaults_duration_comment, 1, 0, 1, 1)
        self.input_lineedit_defaults_downtime_comment = QtWidgets.QLineEdit(self.label_defaults_downtime)
        self.input_lineedit_defaults_downtime_comment.setObjectName("input_lineedit_defaults_downtime_comment")
        self.gridLayout_10.addWidget(self.input_lineedit_defaults_downtime_comment, 3, 1, 1, 1)
        self.gridLayout_9 = QtWidgets.QGridLayout()
        self.gridLayout_9.setContentsMargins(-1, 5, 5, 5)
        self.gridLayout_9.setSpacing(5)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.input_radiobutton_defaults_downtime_type_flexible = QtWidgets.QRadioButton(self.label_defaults_downtime)
        self.input_radiobutton_defaults_downtime_type_flexible.setObjectName("input_radiobutton_defaults_downtime_type_flexible")
        self.gridLayout_9.addWidget(self.input_radiobutton_defaults_downtime_type_flexible, 1, 1, 1, 1)
        self.input_radiobutton_defaults_downtime_type_fixed = QtWidgets.QRadioButton(self.label_defaults_downtime)
        self.input_radiobutton_defaults_downtime_type_fixed.setObjectName("input_radiobutton_defaults_downtime_type_fixed")
        self.gridLayout_9.addWidget(self.input_radiobutton_defaults_downtime_type_fixed, 0, 1, 1, 1)
        self.label_defaults_downtime_type = QtWidgets.QLabel(self.label_defaults_downtime)
        self.label_defaults_downtime_type.setObjectName("label_defaults_downtime_type")
        self.gridLayout_9.addWidget(self.label_defaults_downtime_type, 0, 0, 1, 1)
        spacerItem13 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_9.addItem(spacerItem13, 0, 2, 1, 1)
        self.gridLayout_10.addLayout(self.gridLayout_9, 0, 0, 1, 2)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setContentsMargins(-1, 5, 5, 5)
        self.horizontalLayout_8.setSpacing(5)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.input_spinbox_defaults_downtime_duration_hours = QtWidgets.QSpinBox(self.label_defaults_downtime)
        self.input_spinbox_defaults_downtime_duration_hours.setObjectName("input_spinbox_defaults_downtime_duration_hours")
        self.horizontalLayout_8.addWidget(self.input_spinbox_defaults_downtime_duration_hours)
        self.label_duration_hour = QtWidgets.QLabel(self.label_defaults_downtime)
        self.label_duration_hour.setObjectName("label_duration_hour")
        self.horizontalLayout_8.addWidget(self.label_duration_hour)
        self.input_spinbox_defaults_downtime_duration_minutes = QtWidgets.QSpinBox(self.label_defaults_downtime)
        self.input_spinbox_defaults_downtime_duration_minutes.setObjectName("input_spinbox_defaults_downtime_duration_minutes")
        self.horizontalLayout_8.addWidget(self.input_spinbox_defaults_downtime_duration_minutes)
        self.label_duration_minutes = QtWidgets.QLabel(self.label_defaults_downtime)
        self.label_duration_minutes.setObjectName("label_duration_minutes")
        self.horizontalLayout_8.addWidget(self.label_duration_minutes)
        spacerItem14 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem14)
        self.gridLayout_10.addLayout(self.horizontalLayout_8, 1, 1, 1, 1)
        self.verticalLayout_9.addWidget(self.label_defaults_downtime)
        self.label_acknowledge_submit_result = QtWidgets.QGroupBox(self.tab_defaults)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_acknowledge_submit_result.sizePolicy().hasHeightForWidth())
        self.label_acknowledge_submit_result.setSizePolicy(sizePolicy)
        self.label_acknowledge_submit_result.setObjectName("label_acknowledge_submit_result")
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout(self.label_acknowledge_submit_result)
        self.horizontalLayout_14.setContentsMargins(10, 10, 10, 10)
        self.horizontalLayout_14.setSpacing(5)
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.label_defaults_submit_check_result_comment = QtWidgets.QLabel(self.label_acknowledge_submit_result)
        self.label_defaults_submit_check_result_comment.setObjectName("label_defaults_submit_check_result_comment")
        self.horizontalLayout_14.addWidget(self.label_defaults_submit_check_result_comment)
        self.input_lineedit_defaults_submit_check_result_comment = QtWidgets.QLineEdit(self.label_acknowledge_submit_result)
        self.input_lineedit_defaults_submit_check_result_comment.setObjectName("input_lineedit_defaults_submit_check_result_comment")
        self.horizontalLayout_14.addWidget(self.input_lineedit_defaults_submit_check_result_comment)
        self.verticalLayout_9.addWidget(self.label_acknowledge_submit_result)
        spacerItem15 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_9.addItem(spacerItem15)
        self.tabs.addTab(self.tab_defaults, "")
        self.verticalLayout.addWidget(self.tabs)
        self.button_box = QtWidgets.QDialogButtonBox(settings_main)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.button_box.sizePolicy().hasHeightForWidth())
        self.button_box.setSizePolicy(sizePolicy)
        self.button_box.setOrientation(QtCore.Qt.Horizontal)
        self.button_box.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.button_box.setObjectName("button_box")
        self.verticalLayout.addWidget(self.button_box)

        self.retranslateUi(settings_main)
        self.tabs.setCurrentIndex(6)
        self.button_box.accepted.connect(settings_main.accept)
        self.button_box.rejected.connect(settings_main.reject)
        QtCore.QMetaObject.connectSlotsByName(settings_main)
        settings_main.setTabOrder(self.list_servers, self.button_new_server)
        settings_main.setTabOrder(self.button_new_server, self.button_edit_server)
        settings_main.setTabOrder(self.button_edit_server, self.button_copy_server)
        settings_main.setTabOrder(self.button_copy_server, self.button_delete_server)
        settings_main.setTabOrder(self.button_delete_server, self.input_spinbox_update_interval_seconds)
        settings_main.setTabOrder(self.input_spinbox_update_interval_seconds, self.input_checkbox_use_system_keyring)
        settings_main.setTabOrder(self.input_checkbox_use_system_keyring, self.input_checkbox_debug_mode)
        settings_main.setTabOrder(self.input_checkbox_debug_mode, self.input_checkbox_debug_to_file)
        settings_main.setTabOrder(self.input_checkbox_debug_to_file, self.input_lineedit_debug_file)
        settings_main.setTabOrder(self.input_lineedit_debug_file, self.input_checkbox_check_for_new_version)
        settings_main.setTabOrder(self.input_checkbox_check_for_new_version, self.button_check_for_new_version_now)
        settings_main.setTabOrder(self.button_check_for_new_version_now, self.input_radiobutton_long_display)
        settings_main.setTabOrder(self.input_radiobutton_long_display, self.input_radiobutton_short_display)
        settings_main.setTabOrder(self.input_radiobutton_short_display, self.input_radiobutton_statusbar_floating)
        settings_main.setTabOrder(self.input_radiobutton_statusbar_floating, self.input_radiobutton_icon_in_systray)
        settings_main.setTabOrder(self.input_radiobutton_icon_in_systray, self.input_radiobutton_fullscreen)
        settings_main.setTabOrder(self.input_radiobutton_fullscreen, self.input_checkbox_systray_offset_use)
        settings_main.setTabOrder(self.input_checkbox_systray_offset_use, self.input_spinbox_systray_offset)
        settings_main.setTabOrder(self.input_spinbox_systray_offset, self.input_combobox_fullscreen_display)
        settings_main.setTabOrder(self.input_combobox_fullscreen_display, self.button_fontchooser)
        settings_main.setTabOrder(self.button_fontchooser, self.button_default_font)
        settings_main.setTabOrder(self.button_default_font, self.input_radiobutton_popup_details_hover)
        settings_main.setTabOrder(self.input_radiobutton_popup_details_hover, self.input_radiobutton_popup_details_clicking)
        settings_main.setTabOrder(self.input_radiobutton_popup_details_clicking, self.input_radiobutton_close_details_hover)
        settings_main.setTabOrder(self.input_radiobutton_close_details_hover, self.input_radiobutton_close_details_clicking)
        settings_main.setTabOrder(self.input_radiobutton_close_details_clicking, self.input_radiobutton_close_details_clicking_somewhere)
        settings_main.setTabOrder(self.input_radiobutton_close_details_clicking_somewhere, self.input_checkbox_highlight_new_events)
        settings_main.setTabOrder(self.input_checkbox_highlight_new_events, self.input_checkbox_show_tooltips)
        settings_main.setTabOrder(self.input_checkbox_show_tooltips, self.input_combobox_default_sort_field)
        settings_main.setTabOrder(self.input_combobox_default_sort_field, self.input_combobox_default_sort_order)
        settings_main.setTabOrder(self.input_combobox_default_sort_order, self.input_checkbox_filter_all_down_hosts)
        settings_main.setTabOrder(self.input_checkbox_filter_all_down_hosts, self.input_checkbox_filter_all_unreachable_hosts)
        settings_main.setTabOrder(self.input_checkbox_filter_all_unreachable_hosts, self.input_checkbox_filter_all_flapping_hosts)
        settings_main.setTabOrder(self.input_checkbox_filter_all_flapping_hosts, self.input_checkbox_filter_all_critical_services)
        settings_main.setTabOrder(self.input_checkbox_filter_all_critical_services, self.input_checkbox_filter_all_flapping_services)
        settings_main.setTabOrder(self.input_checkbox_filter_all_flapping_services, self.input_checkbox_filter_all_unknown_services)
        settings_main.setTabOrder(self.input_checkbox_filter_all_unknown_services, self.input_checkbox_filter_all_warning_services)
        settings_main.setTabOrder(self.input_checkbox_filter_all_warning_services, self.input_checkbox_filter_all_information_services)
        settings_main.setTabOrder(self.input_checkbox_filter_all_information_services, self.input_checkbox_filter_all_average_services)
        settings_main.setTabOrder(self.input_checkbox_filter_all_average_services, self.input_checkbox_filter_all_disaster_services)
        settings_main.setTabOrder(self.input_checkbox_filter_all_disaster_services, self.input_checkbox_filter_all_high_services)
        settings_main.setTabOrder(self.input_checkbox_filter_all_high_services, self.input_checkbox_filter_acknowledged_hosts_services)
        settings_main.setTabOrder(self.input_checkbox_filter_acknowledged_hosts_services, self.input_checkbox_filter_hosts_services_disabled_notifications)
        settings_main.setTabOrder(self.input_checkbox_filter_hosts_services_disabled_notifications, self.input_checkbox_filter_hosts_services_disabled_checks)
        settings_main.setTabOrder(self.input_checkbox_filter_hosts_services_disabled_checks, self.input_checkbox_filter_hosts_services_maintenance)
        settings_main.setTabOrder(self.input_checkbox_filter_hosts_services_maintenance, self.input_checkbox_filter_services_on_acknowledged_hosts)
        settings_main.setTabOrder(self.input_checkbox_filter_services_on_acknowledged_hosts, self.input_checkbox_filter_services_on_down_hosts)
        settings_main.setTabOrder(self.input_checkbox_filter_services_on_down_hosts, self.input_checkbox_filter_services_on_hosts_in_maintenance)
        settings_main.setTabOrder(self.input_checkbox_filter_services_on_hosts_in_maintenance, self.input_checkbox_filter_services_on_unreachable_hosts)
        settings_main.setTabOrder(self.input_checkbox_filter_services_on_unreachable_hosts, self.input_checkbox_filter_hosts_in_soft_state)
        settings_main.setTabOrder(self.input_checkbox_filter_hosts_in_soft_state, self.input_checkbox_filter_services_in_soft_state)
        settings_main.setTabOrder(self.input_checkbox_filter_services_in_soft_state, self.input_checkbox_re_host_enabled)
        settings_main.setTabOrder(self.input_checkbox_re_host_enabled, self.input_lineedit_re_host_pattern)
        settings_main.setTabOrder(self.input_lineedit_re_host_pattern, self.input_checkbox_re_host_reverse)
        settings_main.setTabOrder(self.input_checkbox_re_host_reverse, self.input_checkbox_re_service_enabled)
        settings_main.setTabOrder(self.input_checkbox_re_service_enabled, self.input_lineedit_re_service_pattern)
        settings_main.setTabOrder(self.input_lineedit_re_service_pattern, self.input_checkbox_re_service_reverse)
        settings_main.setTabOrder(self.input_checkbox_re_service_reverse, self.input_checkbox_re_status_information_enabled)
        settings_main.setTabOrder(self.input_checkbox_re_status_information_enabled, self.input_lineedit_re_status_information_pattern)
        settings_main.setTabOrder(self.input_lineedit_re_status_information_pattern, self.input_checkbox_re_status_information_reverse)
        settings_main.setTabOrder(self.input_checkbox_re_status_information_reverse, self.input_checkbox_re_duration_enabled)
        settings_main.setTabOrder(self.input_checkbox_re_duration_enabled, self.input_lineedit_re_duration_pattern)
        settings_main.setTabOrder(self.input_lineedit_re_duration_pattern, self.input_checkbox_re_duration_reverse)
        settings_main.setTabOrder(self.input_checkbox_re_duration_reverse, self.input_checkbox_re_attempt_enabled)
        settings_main.setTabOrder(self.input_checkbox_re_attempt_enabled, self.input_lineedit_re_attempt_pattern)
        settings_main.setTabOrder(self.input_lineedit_re_attempt_pattern, self.input_checkbox_re_attempt_reverse)
        settings_main.setTabOrder(self.input_checkbox_re_attempt_reverse, self.input_checkbox_re_groups_enabled)
        settings_main.setTabOrder(self.input_checkbox_re_groups_enabled, self.input_lineedit_re_groups_pattern)
        settings_main.setTabOrder(self.input_lineedit_re_groups_pattern, self.input_checkbox_re_groups_reverse)
        settings_main.setTabOrder(self.input_checkbox_re_groups_reverse, self.list_actions)
        settings_main.setTabOrder(self.list_actions, self.button_new_action)
        settings_main.setTabOrder(self.button_new_action, self.button_edit_action)
        settings_main.setTabOrder(self.button_edit_action, self.button_copy_action)
        settings_main.setTabOrder(self.button_copy_action, self.button_delete_action)
        settings_main.setTabOrder(self.button_delete_action, self.input_radiobutton_connect_by_host)
        settings_main.setTabOrder(self.input_radiobutton_connect_by_host, self.input_radiobutton_connect_by_dns)
        settings_main.setTabOrder(self.input_radiobutton_connect_by_dns, self.input_radiobutton_connect_by_ip)
        settings_main.setTabOrder(self.input_radiobutton_connect_by_ip, self.input_radiobutton_use_default_browser)
        settings_main.setTabOrder(self.input_radiobutton_use_default_browser, self.input_radiobutton_use_custom_browser)
        settings_main.setTabOrder(self.input_radiobutton_use_custom_browser, self.input_lineedit_custom_browser)
        settings_main.setTabOrder(self.input_lineedit_custom_browser, self.button_choose_browser)
        settings_main.setTabOrder(self.button_choose_browser, self.input_checkbox_notification)
        settings_main.setTabOrder(self.input_checkbox_notification, self.input_checkbox_notify_if_warning)
        settings_main.setTabOrder(self.input_checkbox_notify_if_warning, self.input_checkbox_notify_if_critical)
        settings_main.setTabOrder(self.input_checkbox_notify_if_critical, self.input_checkbox_notify_if_unknown)
        settings_main.setTabOrder(self.input_checkbox_notify_if_unknown, self.input_checkbox_notify_if_unreachable)
        settings_main.setTabOrder(self.input_checkbox_notify_if_unreachable, self.input_checkbox_notify_if_down)
        settings_main.setTabOrder(self.input_checkbox_notify_if_down, self.input_checkbox_notify_if_information)
        settings_main.setTabOrder(self.input_checkbox_notify_if_information, self.input_checkbox_notify_if_disaster)
        settings_main.setTabOrder(self.input_checkbox_notify_if_disaster, self.input_checkbox_notify_if_average)
        settings_main.setTabOrder(self.input_checkbox_notify_if_average, self.input_checkbox_notify_if_high)
        settings_main.setTabOrder(self.input_checkbox_notify_if_high, self.input_checkbox_notification_flashing)
        settings_main.setTabOrder(self.input_checkbox_notification_flashing, self.input_checkbox_notification_desktop)
        settings_main.setTabOrder(self.input_checkbox_notification_desktop, self.input_checkbox_notification_sound)
        settings_main.setTabOrder(self.input_checkbox_notification_sound, self.input_checkbox_notification_sound_repeat)
        settings_main.setTabOrder(self.input_checkbox_notification_sound_repeat, self.input_radiobutton_notification_default_sound)
        settings_main.setTabOrder(self.input_radiobutton_notification_default_sound, self.input_radiobutton_notification_custom_sound)
        settings_main.setTabOrder(self.input_radiobutton_notification_custom_sound, self.input_lineedit_notification_custom_sound_warning)
        settings_main.setTabOrder(self.input_lineedit_notification_custom_sound_warning, self.button_choose_warning)
        settings_main.setTabOrder(self.button_choose_warning, self.button_play_warning)
        settings_main.setTabOrder(self.button_play_warning, self.input_lineedit_notification_custom_sound_critical)
        settings_main.setTabOrder(self.input_lineedit_notification_custom_sound_critical, self.button_choose_critical)
        settings_main.setTabOrder(self.button_choose_critical, self.button_play_critical)
        settings_main.setTabOrder(self.button_play_critical, self.input_lineedit_notification_custom_sound_down)
        settings_main.setTabOrder(self.input_lineedit_notification_custom_sound_down, self.button_choose_down)
        settings_main.setTabOrder(self.button_choose_down, self.button_play_down)
        settings_main.setTabOrder(self.button_play_down, self.input_checkbox_notification_actions)
        settings_main.setTabOrder(self.input_checkbox_notification_actions, self.input_checkbox_notification_action_warning)
        settings_main.setTabOrder(self.input_checkbox_notification_action_warning, self.input_lineedit_notification_action_warning_string)
        settings_main.setTabOrder(self.input_lineedit_notification_action_warning_string, self.input_checkbox_notification_action_critical)
        settings_main.setTabOrder(self.input_checkbox_notification_action_critical, self.input_lineedit_notification_action_critical_string)
        settings_main.setTabOrder(self.input_lineedit_notification_action_critical_string, self.input_checkbox_notification_action_down)
        settings_main.setTabOrder(self.input_checkbox_notification_action_down, self.input_lineedit_notification_action_down_string)
        settings_main.setTabOrder(self.input_lineedit_notification_action_down_string, self.input_checkbox_notification_action_ok)
        settings_main.setTabOrder(self.input_checkbox_notification_action_ok, self.input_lineedit_notification_action_ok_string)
        settings_main.setTabOrder(self.input_lineedit_notification_action_ok_string, self.input_checkbox_notification_custom_action)
        settings_main.setTabOrder(self.input_checkbox_notification_custom_action, self.input_lineedit_notification_custom_action_string)
        settings_main.setTabOrder(self.input_lineedit_notification_custom_action_string, self.input_button_color_ok_text)
        settings_main.setTabOrder(self.input_button_color_ok_text, self.input_button_color_ok_background)
        settings_main.setTabOrder(self.input_button_color_ok_background, self.input_button_color_information_text)
        settings_main.setTabOrder(self.input_button_color_information_text, self.input_button_color_information_background)
        settings_main.setTabOrder(self.input_button_color_information_background, self.input_button_color_warning_text)
        settings_main.setTabOrder(self.input_button_color_warning_text, self.input_button_color_warning_background)
        settings_main.setTabOrder(self.input_button_color_warning_background, self.input_button_color_average_text)
        settings_main.setTabOrder(self.input_button_color_average_text, self.input_button_color_average_background)
        settings_main.setTabOrder(self.input_button_color_average_background, self.input_button_color_high_text)
        settings_main.setTabOrder(self.input_button_color_high_text, self.input_button_color_high_background)
        settings_main.setTabOrder(self.input_button_color_high_background, self.input_button_color_critical_text)
        settings_main.setTabOrder(self.input_button_color_critical_text, self.input_button_color_critical_background)
        settings_main.setTabOrder(self.input_button_color_critical_background, self.input_button_color_disaster_text)
        settings_main.setTabOrder(self.input_button_color_disaster_text, self.input_button_color_disaster_background)
        settings_main.setTabOrder(self.input_button_color_disaster_background, self.input_button_color_unknown_text)
        settings_main.setTabOrder(self.input_button_color_unknown_text, self.input_button_color_unknown_background)
        settings_main.setTabOrder(self.input_button_color_unknown_background, self.input_button_color_unreachable_text)
        settings_main.setTabOrder(self.input_button_color_unreachable_text, self.input_button_color_unreachable_background)
        settings_main.setTabOrder(self.input_button_color_unreachable_background, self.input_button_color_down_text)
        settings_main.setTabOrder(self.input_button_color_down_text, self.input_button_color_down_background)
        settings_main.setTabOrder(self.input_button_color_down_background, self.input_button_color_error_text)
        settings_main.setTabOrder(self.input_button_color_error_text, self.input_button_color_error_background)
        settings_main.setTabOrder(self.input_button_color_error_background, self.button_colors_reset)
        settings_main.setTabOrder(self.button_colors_reset, self.button_colors_defaults)
        settings_main.setTabOrder(self.button_colors_defaults, self.input_checkbox_defaults_acknowledge_sticky)
        settings_main.setTabOrder(self.input_checkbox_defaults_acknowledge_sticky, self.input_checkbox_defaults_acknowledge_send_notification)
        settings_main.setTabOrder(self.input_checkbox_defaults_acknowledge_send_notification, self.input_checkbox_defaults_acknowledge_persistent_comment)
        settings_main.setTabOrder(self.input_checkbox_defaults_acknowledge_persistent_comment, self.input_checkbox_defaults_acknowledge_all_services)
        settings_main.setTabOrder(self.input_checkbox_defaults_acknowledge_all_services, self.input_lineedit_defaults_acknowledge_comment)
        settings_main.setTabOrder(self.input_lineedit_defaults_acknowledge_comment, self.input_checkbox_defaults_acknowledge_expire)
        settings_main.setTabOrder(self.input_checkbox_defaults_acknowledge_expire, self.input_spinbox_defaults_acknowledge_expire_duration_hours)
        settings_main.setTabOrder(self.input_spinbox_defaults_acknowledge_expire_duration_hours, self.input_spinbox_defaults_acknowledge_expire_duration_minutes)
        settings_main.setTabOrder(self.input_spinbox_defaults_acknowledge_expire_duration_minutes, self.input_radiobutton_defaults_downtime_type_fixed)
        settings_main.setTabOrder(self.input_radiobutton_defaults_downtime_type_fixed, self.input_radiobutton_defaults_downtime_type_flexible)
        settings_main.setTabOrder(self.input_radiobutton_defaults_downtime_type_flexible, self.input_spinbox_defaults_downtime_duration_hours)
        settings_main.setTabOrder(self.input_spinbox_defaults_downtime_duration_hours, self.input_spinbox_defaults_downtime_duration_minutes)
        settings_main.setTabOrder(self.input_spinbox_defaults_downtime_duration_minutes, self.input_lineedit_defaults_downtime_comment)
        settings_main.setTabOrder(self.input_lineedit_defaults_downtime_comment, self.input_lineedit_defaults_submit_check_result_comment)
        settings_main.setTabOrder(self.input_lineedit_defaults_submit_check_result_comment, self.tabs)
        settings_main.setTabOrder(self.tabs, self.input_checkbox_show_grid)
        settings_main.setTabOrder(self.input_checkbox_show_grid, self.input_checkbox_grid_use_custom_intensity)
        settings_main.setTabOrder(self.input_checkbox_grid_use_custom_intensity, self.input_slider_grid_alternation_intensity)
        settings_main.setTabOrder(self.input_slider_grid_alternation_intensity, self.input_radiobutton_windowed)
        settings_main.setTabOrder(self.input_radiobutton_windowed, self.input_lineedit_notification_custom_action_separator)
        settings_main.setTabOrder(self.input_lineedit_notification_custom_action_separator, self.input_checkbox_notification_custom_action_single)

    def retranslateUi(self, settings_main):
        _translate = QtCore.QCoreApplication.translate
        settings_main.setWindowTitle(_translate("settings_main", "Nagstamon 2.0 settings"))
        self.input_checkbox_debug_mode.setText(_translate("settings_main", "Debug mode"))
        self.input_checkbox_debug_to_file.setText(_translate("settings_main", "Debug to file:"))
        self.button_new_server.setText(_translate("settings_main", "New server..."))
        self.button_edit_server.setText(_translate("settings_main", "Edit server..."))
        self.button_copy_server.setText(_translate("settings_main", "Copy server..."))
        self.button_delete_server.setText(_translate("settings_main", "Delete server"))
        self.input_checkbox_use_system_keyring.setText(_translate("settings_main", "Use system keyring for server credentials"))
        self.label_update_interval_seconds.setText(_translate("settings_main", "Update interval:"))
        self.label_interval_seconds.setText(_translate("settings_main", "seconds"))
        self.input_checkbox_check_for_new_version.setText(_translate("settings_main", "Check for new version at startup"))
        self.button_check_for_new_version_now.setText(_translate("settings_main", "Check for new version now"))
        self.tabs.setTabText(self.tabs.indexOf(self.tab_servers), _translate("settings_main", "Servers"))
        self.groupbox_display_size.setTitle(_translate("settings_main", "Statusbar display size:"))
        self.input_radiobutton_short_display.setText(_translate("settings_main", "Short  [ 1 | 4 ]"))
        self.input_radiobutton_long_display.setText(_translate("settings_main", "Long  [ 1 WARNING | 4 CRITICAL ]"))
        self.groupbox_detailed_summary_popup.setTitle(_translate("settings_main", "Statusbar details popup:"))
        self.input_radiobutton_close_details_clicking.setText(_translate("settings_main", "Close when clicking statusbar"))
        self.input_radiobutton_popup_details_clicking.setText(_translate("settings_main", "Popup when clicking statusbar"))
        self.input_radiobutton_popup_details_hover.setText(_translate("settings_main", "Popup when hovering over statusbar"))
        self.input_radiobutton_close_details_hover.setText(_translate("settings_main", "Close when hovering out of popup"))
        self.input_radiobutton_close_details_clicking_somewhere.setText(_translate("settings_main", "Close when clicking somewhere"))
        self.input_checkbox_highlight_new_events.setText(_translate("settings_main", "Highlight new events in status details overview"))
        self.input_checkbox_show_tooltips.setText(_translate("settings_main", "Show tooltips in status details overview"))
        self.label_default_sort_field.setText(_translate("settings_main", "Default sort field:"))
        self.label_default_sort_order.setText(_translate("settings_main", "Default sort order:"))
        self.groupbox_appearance.setTitle(_translate("settings_main", "Appearance:"))
        self.input_radiobutton_icon_in_systray.setText(_translate("settings_main", "Icon in systray"))
        self.input_checkbox_systray_offset_use.setText(_translate("settings_main", "Use offset to correct position problems"))
        self.label_fullscreen_display.setText(_translate("settings_main", "Display to use:"))
        self.label_offset_statuswindow.setText(_translate("settings_main", "Offset for statuswindow:"))
        self.input_radiobutton_fullscreen.setText(_translate("settings_main", "Fullscreen"))
        self.input_radiobutton_statusbar_floating.setText(_translate("settings_main", "Floating statusbar"))
        self.input_radiobutton_windowed.setText(_translate("settings_main", "Window"))
        self.groupbox_font.setTitle(_translate("settings_main", "Font:"))
        self.label_font.setText(_translate("settings_main", "The CRITICAL Fox jumped over the WARNING dog."))
        self.button_fontchooser.setText(_translate("settings_main", "Change Font..."))
        self.button_default_font.setText(_translate("settings_main", "Revert to default font"))
        self.tabs.setTabText(self.tabs.indexOf(self.tab_display), _translate("settings_main", "Display"))
        self.input_checkbox_re_attempt_enabled.setText(_translate("settings_main", "Regular expression for attempt"))
        self.input_checkbox_re_service_enabled.setText(_translate("settings_main", "Regular expression for services"))
        self.input_checkbox_re_status_information_reverse.setText(_translate("settings_main", "reverse"))
        self.input_checkbox_re_duration_reverse.setText(_translate("settings_main", "reverse"))
        self.input_checkbox_re_status_information_enabled.setText(_translate("settings_main", "Regular expression for status informations"))
        self.input_checkbox_re_service_reverse.setText(_translate("settings_main", "reverse"))
        self.input_checkbox_re_groups_enabled.setText(_translate("settings_main", "Regular expression for groups"))
        self.input_checkbox_re_attempt_reverse.setText(_translate("settings_main", "reverse"))
        self.input_checkbox_re_duration_enabled.setText(_translate("settings_main", "Regular expression for duration"))
        self.input_checkbox_re_groups_reverse.setText(_translate("settings_main", "reverse"))
        self.label_python_re.setText(_translate("settings_main", "<a href=http://docs.python.org/howto/regex.html>See Python Regular Expressions HOWTO for filtering details.</a>"))
        self.input_checkbox_re_host_enabled.setText(_translate("settings_main", "Regular expression for hosts"))
        self.groupbox_filters.setTitle(_translate("settings_main", "Filter out the following:"))
        self.input_checkbox_filter_all_down_hosts.setText(_translate("settings_main", "All down hosts"))
        self.input_checkbox_filter_all_unreachable_hosts.setText(_translate("settings_main", "All unreachable hosts"))
        self.input_checkbox_filter_all_unreachable_services.setText(_translate("settings_main", "All unreachable services"))
        self.input_checkbox_filter_all_flapping_hosts.setText(_translate("settings_main", "All flapping hosts"))
        self.input_checkbox_filter_all_critical_services.setText(_translate("settings_main", "All critical services"))
        self.input_checkbox_filter_acknowledged_hosts_services.setText(_translate("settings_main", "Acknowledged hosts and services"))
        self.input_checkbox_filter_hosts_services_disabled_notifications.setText(_translate("settings_main", "Hosts and services with disabled notifications"))
        self.input_checkbox_filter_hosts_services_disabled_checks.setText(_translate("settings_main", "Hosts and services with disabled checks"))
        self.input_checkbox_filter_hosts_services_maintenance.setText(_translate("settings_main", "Hosts and services down for maintenance"))
        self.input_checkbox_filter_services_on_acknowledged_hosts.setText(_translate("settings_main", "Services on acknowledged hosts"))
        self.input_checkbox_filter_services_on_down_hosts.setText(_translate("settings_main", "Services on down hosts"))
        self.input_checkbox_filter_all_high_services.setText(_translate("settings_main", "All high services"))
        self.input_checkbox_filter_all_disaster_services.setText(_translate("settings_main", "All disaster services"))
        self.input_checkbox_filter_all_flapping_services.setText(_translate("settings_main", "All flapping services"))
        self.input_checkbox_filter_all_unknown_services.setText(_translate("settings_main", "All unknown services"))
        self.input_checkbox_filter_all_warning_services.setText(_translate("settings_main", "All warning services"))
        self.input_checkbox_filter_all_information_services.setText(_translate("settings_main", "All information services"))
        self.input_checkbox_filter_all_average_services.setText(_translate("settings_main", "All average services"))
        self.input_checkbox_filter_services_on_hosts_in_maintenance.setText(_translate("settings_main", "Services on hosts in maintenance"))
        self.input_checkbox_filter_services_on_unreachable_hosts.setText(_translate("settings_main", "Services on unreachable hosts"))
        self.input_checkbox_filter_hosts_in_soft_state.setText(_translate("settings_main", "Hosts in soft state"))
        self.input_checkbox_filter_services_in_soft_state.setText(_translate("settings_main", "Services in soft state"))
        self.input_checkbox_re_host_reverse.setText(_translate("settings_main", "reverse"))
        self.tabs.setTabText(self.tabs.indexOf(self.tab_filters), _translate("settings_main", "Filters"))
        self.button_new_action.setText(_translate("settings_main", "New action..."))
        self.button_edit_action.setText(_translate("settings_main", "Edit action..."))
        self.button_copy_action.setText(_translate("settings_main", "Copy action..."))
        self.button_delete_action.setText(_translate("settings_main", "Delete action"))
        self.groupbox_connection_method.setTitle(_translate("settings_main", "Connection method:"))
        self.input_radiobutton_connect_by_host.setText(_translate("settings_main", "Hostname provided by monitor"))
        self.input_radiobutton_connect_by_dns.setText(_translate("settings_main", "DNS name by looking up IP address"))
        self.input_radiobutton_connect_by_ip.setText(_translate("settings_main", "IP resolved by hostname"))
        self.groupbox_browser.setTitle(_translate("settings_main", "Browser:"))
        self.input_radiobutton_use_default_browser.setText(_translate("settings_main", "Use default browser"))
        self.input_radiobutton_use_custom_browser.setText(_translate("settings_main", "Use alternative browser"))
        self.groupbox_custom_browser.setTitle(_translate("settings_main", "Custom browser:"))
        self.button_choose_browser.setText(_translate("settings_main", "Choose browser..."))
        self.tabs.setTabText(self.tabs.indexOf(self.tab_actions), _translate("settings_main", "Actions"))
        self.input_checkbox_notification.setText(_translate("settings_main", "Enable notification"))
        self.notification_groupbox.setTitle(_translate("settings_main", "Notifications:"))
        self.input_checkbox_notify_if_warning.setText(_translate("settings_main", "WARNING"))
        self.input_checkbox_notify_if_critical.setText(_translate("settings_main", "CRITICAL"))
        self.input_checkbox_notify_if_unknown.setText(_translate("settings_main", "UNKNOWN"))
        self.input_checkbox_notify_if_unreachable.setText(_translate("settings_main", "UNREACHABLE"))
        self.input_checkbox_notify_if_down.setText(_translate("settings_main", "DOWN"))
        self.input_checkbox_notify_if_information.setText(_translate("settings_main", "INFORMATION"))
        self.input_checkbox_notify_if_disaster.setText(_translate("settings_main", "DISASTER"))
        self.input_checkbox_notify_if_average.setText(_translate("settings_main", "AVERAGE"))
        self.input_checkbox_notify_if_high.setText(_translate("settings_main", "HIGH"))
        self.input_checkbox_notification_flashing.setText(_translate("settings_main", "Flashing statusbar/appindicator/systray icon"))
        self.input_checkbox_notification_desktop.setText(_translate("settings_main", "Desktop notification"))
        self.input_checkbox_notification_sound.setText(_translate("settings_main", "Enable sound"))
        self.notification_sounds_groupbox.setTitle(_translate("settings_main", "Sounds:"))
        self.notification_custom_sounds_groupbox.setTitle(_translate("settings_main", "Custom sounds:"))
        self.button_choose_critical.setText(_translate("settings_main", "Choose file..."))
        self.button_play_warning.setText(_translate("settings_main", "Play"))
        self.label_notification_sound_options_custom_sounds_warning.setText(_translate("settings_main", "WARNING:"))
        self.label_notification_sound_options_custom_sounds_critical.setText(_translate("settings_main", "CRITICAL:"))
        self.button_choose_down.setText(_translate("settings_main", "Choose file..."))
        self.button_choose_warning.setText(_translate("settings_main", "Choose file..."))
        self.button_play_critical.setText(_translate("settings_main", "Play"))
        self.label_notification_sound_options_custom_sounds_down.setText(_translate("settings_main", "DOWN:"))
        self.button_play_down.setText(_translate("settings_main", "Play"))
        self.input_checkbox_notification_sound_repeat.setText(_translate("settings_main", "Repeat sound until notification has been noticed"))
        self.input_radiobutton_notification_default_sound.setText(_translate("settings_main", "Use default Nagios sounds"))
        self.input_radiobutton_notification_custom_sound.setText(_translate("settings_main", "Use custom sounds"))
        self.input_checkbox_notification_actions.setText(_translate("settings_main", "Enable notification actions"))
        self.notification_actions_groupbox.setTitle(_translate("settings_main", "Notification actions:"))
        self.input_lineedit_notification_action_ok_string.setToolTip(_translate("settings_main", "Just one single command to be executed like starting some blinking light etc."))
        self.input_checkbox_notification_action_critical.setText(_translate("settings_main", "CRITICAL"))
        self.input_checkbox_notification_action_down.setText(_translate("settings_main", "DOWN"))
        self.input_checkbox_notification_action_ok.setText(_translate("settings_main", "OK"))
        self.input_checkbox_notification_action_warning.setText(_translate("settings_main", "WARNING"))
        self.input_lineedit_notification_action_down_string.setToolTip(_translate("settings_main", "Just one single command to be executed like starting some blinking light etc."))
        self.input_checkbox_notification_custom_action.setText(_translate("settings_main", "Use custom notification action"))
        self.notification_custom_action_groupbox.setTitle(_translate("settings_main", "Custom notification action:"))
        self.label_notification_custom_action_string.setText(_translate("settings_main", "Action string:"))
        self.label_notification_custom_action_separator.setText(_translate("settings_main", "Event separator:"))
        self.input_lineedit_notification_custom_action_separator.setToolTip(_translate("settings_main", "Arbitrarily choosen string or character to separate events in $EVENTS$."))
        self.input_checkbox_notification_custom_action_single.setText(_translate("settings_main", "Run one single action for every event"))
        self.input_lineedit_notification_custom_action_string.setToolTip(_translate("settings_main", "<html><head/><body><p>Available variables for action strings are $EVENTS$ for all events concatenated by the event separator or $EVENT$ if single actions are choosen.</p><p>To get all information into executable the variable should be quoted like \'$EVENT$\'.</p></body></html>"))
        self.input_lineedit_notification_action_critical_string.setToolTip(_translate("settings_main", "Just one single command to be executed like starting some blinking light etc."))
        self.input_lineedit_notification_action_warning_string.setToolTip(_translate("settings_main", "Just one single command to be executed like starting some blinking light etc."))
        self.tabs.setTabText(self.tabs.indexOf(self.tab_notifications), _translate("settings_main", "Notifications"))
        self.label_colors.setText(_translate("settings_main", "Set colors for text and background of status information:"))
        self.states_groupbox.setTitle(_translate("settings_main", "Status:"))
        self.label_color_ok.setText(_translate("settings_main", " OK "))
        self.label_color_information.setText(_translate("settings_main", " INFORMATION"))
        self.label_color_warning.setText(_translate("settings_main", " WARNING "))
        self.label_color_average.setText(_translate("settings_main", " AVERAGE "))
        self.label_color_high.setText(_translate("settings_main", " HIGH "))
        self.label_color_critical.setText(_translate("settings_main", " CRITICAL "))
        self.label_color_disaster.setText(_translate("settings_main", " DISASTER "))
        self.label_color_unknown.setText(_translate("settings_main", " UNKNOWN "))
        self.label_color_unreachable.setText(_translate("settings_main", " UNREACHABLE "))
        self.label_color_down.setText(_translate("settings_main", " DOWN "))
        self.label_color_error.setText(_translate("settings_main", " ERROR "))
        self.text_groupbox.setTitle(_translate("settings_main", "Text:"))
        self.background_groupbox.setTitle(_translate("settings_main", "Background:"))
        self.button_colors_reset.setText(_translate("settings_main", "Reset to previous colors"))
        self.button_colors_defaults.setText(_translate("settings_main", "Revert to default colors"))
        self.groupBox_color_grid.setTitle(_translate("settings_main", "Colored grid:"))
        self.input_checkbox_show_grid.setText(_translate("settings_main", "Use alternating colors for better readability"))
        self.input_checkbox_grid_use_custom_intensity.setText(_translate("settings_main", "Customize intensity of alternation"))
        self.label_intensity_information_0.setText(_translate("settings_main", " INFORMATION"))
        self.label_intensity_information_1.setText(_translate("settings_main", " INFORMATION"))
        self.label_intensity_warning_0.setText(_translate("settings_main", " WARNING"))
        self.label_intensity_warning_1.setText(_translate("settings_main", " WARNING"))
        self.label_intensity_average_0.setText(_translate("settings_main", " AVERAGE"))
        self.label_intensity_average_1.setText(_translate("settings_main", " AVERAGE"))
        self.label_intensity_high_0.setText(_translate("settings_main", " HIGH"))
        self.label_intensity_high_1.setText(_translate("settings_main", " HIGH"))
        self.label_intensity_critical_0.setText(_translate("settings_main", " CRITICAL"))
        self.label_intensity_critical_1.setText(_translate("settings_main", " CRITICAL"))
        self.label_intensity_disaster_0.setText(_translate("settings_main", " DISASTER"))
        self.label_intensity_disaster_1.setText(_translate("settings_main", " DISASTER"))
        self.label_intensity_unknown_0.setText(_translate("settings_main", " UNKNOWN"))
        self.label_intensity_unknown_1.setText(_translate("settings_main", " UNKNOWN"))
        self.label_intensity_unreachable_0.setText(_translate("settings_main", " UNREACHABLE"))
        self.label_intensity_unreachable_1.setText(_translate("settings_main", " UNREACHABLE"))
        self.label_intensity_down_0.setText(_translate("settings_main", " DOWN"))
        self.label_intensity_down_1.setText(_translate("settings_main", " DOWN"))
        self.tabs.setTabText(self.tabs.indexOf(self.tab_colors), _translate("settings_main", "Colors"))
        self.label_defaults.setText(_translate("settings_main", "Set some default settings for default actions:"))
        self.label_defaults_acknowledge.setTitle(_translate("settings_main", "Acknowledgements:"))
        self.input_checkbox_defaults_acknowledge_sticky.setText(_translate("settings_main", "Sticky acknowledgement"))
        self.input_checkbox_defaults_acknowledge_send_notification.setText(_translate("settings_main", "Send notification"))
        self.input_checkbox_defaults_acknowledge_persistent_comment.setText(_translate("settings_main", "Persistent comment"))
        self.input_checkbox_defaults_acknowledge_all_services.setText(_translate("settings_main", "Acknowledge all services on host"))
        self.label_defaults_acknowledge_comment.setText(_translate("settings_main", "Comment:"))
        self.input_checkbox_defaults_acknowledge_expire.setText(_translate("settings_main", "Use expire acknowledgement"))
        self.label_expire_in.setText(_translate("settings_main", "Expire in:  "))
        self.label_expire_in_hours.setText(_translate("settings_main", "hours"))
        self.label_expire_in_minutes.setText(_translate("settings_main", "minutes"))
        self.label_defaults_downtime.setTitle(_translate("settings_main", "Downtime:"))
        self.label_defaults_downtime_comment.setText(_translate("settings_main", "Comment:"))
        self.label_defaults_duration_comment.setText(_translate("settings_main", "Duration:"))
        self.input_radiobutton_defaults_downtime_type_flexible.setText(_translate("settings_main", "Flexible"))
        self.input_radiobutton_defaults_downtime_type_fixed.setText(_translate("settings_main", "Fixed"))
        self.label_defaults_downtime_type.setText(_translate("settings_main", "Type:"))
        self.label_duration_hour.setText(_translate("settings_main", "hours"))
        self.label_duration_minutes.setText(_translate("settings_main", "minutes"))
        self.label_acknowledge_submit_result.setTitle(_translate("settings_main", "Submit check result:"))
        self.label_defaults_submit_check_result_comment.setText(_translate("settings_main", "Comment:"))
        self.tabs.setTabText(self.tabs.indexOf(self.tab_defaults), _translate("settings_main", "Defaults"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    settings_main = QtWidgets.QDialog()
    ui = Ui_settings_main()
    ui.setupUi(settings_main)
    settings_main.show()
    sys.exit(app.exec_())
